# pinterestsdk
Pinterest's REST API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 5.23.0
- Package version: 2.0.0
- Generator version: 7.18.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://github.com/oapicf/pinterest-sdk](https://github.com/oapicf/pinterest-sdk)

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/oapicf/pinterest-sdk.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/oapicf/pinterest-sdk.git`)

Then import the package:
```python
import pinterestsdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pinterestsdk
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import pinterestsdk
from pinterestsdk.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.pinterest.com/v5
# See configuration.py for a list of all supported configuration parameters.
configuration = pinterestsdk.Configuration(
    host = "https://api.pinterest.com/v5"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

configuration.access_token = os.environ["ACCESS_TOKEN"]

configuration.access_token = os.environ["ACCESS_TOKEN"]


# Enter a context with an instance of the API client
with pinterestsdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = pinterestsdk.AdAccountsApi(api_client)
    ad_account_id = 'ad_account_id_example' # str | Unique identifier of an ad account.
    start_date = '2013-10-20' # date | Metric report start date (UTC). Format: YYYY-MM-DD. Cannot be more than 90 days back from today.
    end_date = '2013-10-20' # date | Metric report end date (UTC). Format: YYYY-MM-DD. Cannot be more than 90 days past start_date.
    columns = ['columns_example'] # List[str] | Columns to retrieve, encoded as a comma-separated string. **NOTE**: Any metrics defined as MICRO_DOLLARS returns a value based on the advertiser profile's currency field. For USD,($1/1,000,000, or $0.000001 - one one-ten-thousandth of a cent). it's microdollars. Otherwise, it's in microunits of the advertiser's currency.<br/>For example, if the advertiser's currency is GBP (British pound sterling), all MICRO_DOLLARS fields will be in GBP microunits (1/1,000,000 British pound).<br/>If a column has no value, it may not be returned
    granularity = pinterestsdk.Granularity() # Granularity | TOTAL - metrics are aggregated over the specified date range.<br> DAY - metrics are broken down daily.<br> HOUR - metrics are broken down hourly.<br>WEEKLY - metrics are broken down weekly.<br>MONTHLY - metrics are broken down monthly
    click_window_days = 30 # int | Number of days to use as the conversion attribution window for a pin click action. Applies to Pinterest Tag conversion metrics. Prior conversion tags use their defined attribution windows. If not specified, defaults to `30` days. (optional) (default to 30)
    engagement_window_days = 30 # int | Number of days to use as the conversion attribution window for an engagement action. Engagements include saves, closeups, link clicks, and carousel card swipes. Applies to Pinterest Tag conversion metrics. Prior conversion tags use their defined attribution windows. If not specified, defaults to `30` days.<br> <strong>Note:</strong> This parameter no longer returns new data. However, you can still access historic data through <strong>Sept 30, 2027</strong>. (optional) (default to 30)
    view_window_days = 1 # int | Number of days to use as the conversion attribution window for a view action. Applies to Pinterest Tag conversion metrics. Prior conversion tags use their defined attribution windows. If not specified, defaults to `1` day. (optional) (default to 1)
    conversion_report_time = TIME_OF_AD_ACTION # str | The date by which the conversion metrics returned from this endpoint will be reported. There are two dates associated with a conversion event: the date that the user interacted with the ad, and the date that the user completed a conversion event. (optional) (default to TIME_OF_AD_ACTION)
    reporting_timezone = pinterestsdk.ReportingTimeZone() # ReportingTimeZone | Specify the timezone to be applied for the reporting. This feature is currently in BETA and is not available to all users. (optional)

    try:
        # Get ad account analytics
        api_response = api_instance.ad_account_analytics(ad_account_id, start_date, end_date, columns, granularity, click_window_days=click_window_days, engagement_window_days=engagement_window_days, view_window_days=view_window_days, conversion_report_time=conversion_report_time, reporting_timezone=reporting_timezone)
        print("The response of AdAccountsApi->ad_account_analytics:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AdAccountsApi->ad_account_analytics: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.pinterest.com/v5*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdAccountsApi* | [**ad_account_analytics**](docs/AdAccountsApi.md#ad_account_analytics) | **GET** /ad_accounts/{ad_account_id}/analytics | Get ad account analytics
*AdAccountsApi* | [**ad_account_targeting_analytics_get**](docs/AdAccountsApi.md#ad_account_targeting_analytics_get) | **GET** /ad_accounts/{ad_account_id}/targeting_analytics | Get targeting analytics for an ad account
*AdAccountsApi* | [**ad_accounts_create**](docs/AdAccountsApi.md#ad_accounts_create) | **POST** /ad_accounts | Create ad account
*AdAccountsApi* | [**ad_accounts_get**](docs/AdAccountsApi.md#ad_accounts_get) | **GET** /ad_accounts/{ad_account_id} | Get ad account
*AdAccountsApi* | [**ad_accounts_list**](docs/AdAccountsApi.md#ad_accounts_list) | **GET** /ad_accounts | List ad accounts
*AdAccountsApi* | [**analytics_create_conversion_product_report**](docs/AdAccountsApi.md#analytics_create_conversion_product_report) | **POST** /ad_accounts/{ad_account_id}/reports/brand_category_sku | Create a request for a brand, category, SKU report
*AdAccountsApi* | [**analytics_create_mmm_report**](docs/AdAccountsApi.md#analytics_create_mmm_report) | **POST** /ad_accounts/{ad_account_id}/mmm_reports | Create a request for a Marketing Mix Modeling (MMM) report
*AdAccountsApi* | [**analytics_create_report**](docs/AdAccountsApi.md#analytics_create_report) | **POST** /ad_accounts/{ad_account_id}/reports | Create async request for an account analytics report
*AdAccountsApi* | [**analytics_create_template_report**](docs/AdAccountsApi.md#analytics_create_template_report) | **POST** /ad_accounts/{ad_account_id}/templates/{template_id}/reports | Create async request for an analytics report using a template
*AdAccountsApi* | [**analytics_get_conversion_product_report**](docs/AdAccountsApi.md#analytics_get_conversion_product_report) | **GET** /ad_accounts/{ad_account_id}/reports/brand_category_sku | Get advertiser brand, category, SKU report
*AdAccountsApi* | [**analytics_get_mmm_report**](docs/AdAccountsApi.md#analytics_get_mmm_report) | **GET** /ad_accounts/{ad_account_id}/mmm_reports | Get advertiser Marketing Mix Modeling (MMM) report.
*AdAccountsApi* | [**analytics_get_report**](docs/AdAccountsApi.md#analytics_get_report) | **GET** /ad_accounts/{ad_account_id}/reports | Get the account analytics report created by the async call
*AdAccountsApi* | [**sandbox_delete**](docs/AdAccountsApi.md#sandbox_delete) | **DELETE** /ad_accounts/{ad_account_id}/sandbox | Delete ads data for ad account in API Sandbox
*AdAccountsApi* | [**templates_list**](docs/AdAccountsApi.md#templates_list) | **GET** /ad_accounts/{ad_account_id}/templates | List templates
*AdGroupsApi* | [**ad_groups_analytics**](docs/AdGroupsApi.md#ad_groups_analytics) | **GET** /ad_accounts/{ad_account_id}/ad_groups/analytics | Get ad group analytics
*AdGroupsApi* | [**ad_groups_audience_sizing**](docs/AdGroupsApi.md#ad_groups_audience_sizing) | **POST** /ad_accounts/{ad_account_id}/ad_groups/audience_sizing | Get audience sizing
*AdGroupsApi* | [**ad_groups_bid_floor_get**](docs/AdGroupsApi.md#ad_groups_bid_floor_get) | **POST** /ad_accounts/{ad_account_id}/bid_floor | Get bid floors
*AdGroupsApi* | [**ad_groups_create**](docs/AdGroupsApi.md#ad_groups_create) | **POST** /ad_accounts/{ad_account_id}/ad_groups | Create ad groups
*AdGroupsApi* | [**ad_groups_get**](docs/AdGroupsApi.md#ad_groups_get) | **GET** /ad_accounts/{ad_account_id}/ad_groups/{ad_group_id} | Get ad group
*AdGroupsApi* | [**ad_groups_list**](docs/AdGroupsApi.md#ad_groups_list) | **GET** /ad_accounts/{ad_account_id}/ad_groups | List ad groups
*AdGroupsApi* | [**ad_groups_targeting_analytics_get**](docs/AdGroupsApi.md#ad_groups_targeting_analytics_get) | **GET** /ad_accounts/{ad_account_id}/ad_groups/targeting_analytics | Get targeting analytics for ad groups
*AdGroupsApi* | [**ad_groups_update**](docs/AdGroupsApi.md#ad_groups_update) | **PATCH** /ad_accounts/{ad_account_id}/ad_groups | Update ad groups
*AdsApi* | [**ad_previews_create**](docs/AdsApi.md#ad_previews_create) | **POST** /ad_accounts/{ad_account_id}/ad_previews | Create ad preview with pin or image
*AdsApi* | [**ad_targeting_analytics_get**](docs/AdsApi.md#ad_targeting_analytics_get) | **GET** /ad_accounts/{ad_account_id}/ads/targeting_analytics | Get targeting analytics for ads
*AdsApi* | [**ads_analytics**](docs/AdsApi.md#ads_analytics) | **GET** /ad_accounts/{ad_account_id}/ads/analytics | Get ad analytics
*AdsApi* | [**ads_create**](docs/AdsApi.md#ads_create) | **POST** /ad_accounts/{ad_account_id}/ads | Create ads
*AdsApi* | [**ads_get**](docs/AdsApi.md#ads_get) | **GET** /ad_accounts/{ad_account_id}/ads/{ad_id} | Get ad
*AdsApi* | [**ads_list**](docs/AdsApi.md#ads_list) | **GET** /ad_accounts/{ad_account_id}/ads | List ads
*AdsApi* | [**ads_update**](docs/AdsApi.md#ads_update) | **PATCH** /ad_accounts/{ad_account_id}/ads | Update ads
*AdvancedAuctionApi* | [**advanced_auction_items_get_post**](docs/AdvancedAuctionApi.md#advanced_auction_items_get_post) | **POST** /advanced_auction/items/get | Get item bid options (POST)
*AdvancedAuctionApi* | [**advanced_auction_items_submit_post**](docs/AdvancedAuctionApi.md#advanced_auction_items_submit_post) | **POST** /advanced_auction/items/submit | Operate on item level bid options
*AudienceInsightsApi* | [**audience_insights_get**](docs/AudienceInsightsApi.md#audience_insights_get) | **GET** /ad_accounts/{ad_account_id}/audience_insights | Get audience insights
*AudienceInsightsApi* | [**audience_insights_scope_and_type_get**](docs/AudienceInsightsApi.md#audience_insights_scope_and_type_get) | **GET** /ad_accounts/{ad_account_id}/insights/audiences | Get audience insights scope and type
*AudienceSharingApi* | [**ad_accounts_audiences_shared_accounts_list**](docs/AudienceSharingApi.md#ad_accounts_audiences_shared_accounts_list) | **GET** /ad_accounts/{ad_account_id}/audiences/shared/accounts | List accounts with access to an audience owned by an ad account
*AudienceSharingApi* | [**business_account_audiences_shared_accounts_list**](docs/AudienceSharingApi.md#business_account_audiences_shared_accounts_list) | **GET** /businesses/{business_id}/audiences/shared/accounts | List accounts with access to an audience owned by a business
*AudienceSharingApi* | [**shared_audiences_for_business_list**](docs/AudienceSharingApi.md#shared_audiences_for_business_list) | **GET** /businesses/{business_id}/audiences | List received audiences for a business
*AudienceSharingApi* | [**update_ad_account_to_ad_account_shared_audience**](docs/AudienceSharingApi.md#update_ad_account_to_ad_account_shared_audience) | **PATCH** /ad_accounts/{ad_account_id}/audiences/ad_accounts/shared | Update audience sharing between ad accounts
*AudienceSharingApi* | [**update_ad_account_to_business_shared_audience**](docs/AudienceSharingApi.md#update_ad_account_to_business_shared_audience) | **PATCH** /ad_accounts/{ad_account_id}/audiences/businesses/shared | Update audience sharing from an ad account to businesses
*AudienceSharingApi* | [**update_business_to_ad_account_shared_audience**](docs/AudienceSharingApi.md#update_business_to_ad_account_shared_audience) | **PATCH** /businesses/{business_id}/audiences/ad_accounts/shared | Update audience sharing from a business to ad accounts
*AudienceSharingApi* | [**update_business_to_business_shared_audience**](docs/AudienceSharingApi.md#update_business_to_business_shared_audience) | **PATCH** /businesses/{business_id}/audiences/businesses/shared | Update audience sharing between businesses
*AudiencesApi* | [**audiences_create**](docs/AudiencesApi.md#audiences_create) | **POST** /ad_accounts/{ad_account_id}/audiences | Create audience
*AudiencesApi* | [**audiences_get**](docs/AudiencesApi.md#audiences_get) | **GET** /ad_accounts/{ad_account_id}/audiences/{audience_id} | Get audience
*AudiencesApi* | [**audiences_list**](docs/AudiencesApi.md#audiences_list) | **GET** /ad_accounts/{ad_account_id}/audiences | List audiences
*AudiencesApi* | [**audiences_update**](docs/AudiencesApi.md#audiences_update) | **PATCH** /ad_accounts/{ad_account_id}/audiences/{audience_id} | Update audience
*BillingApi* | [**ads_credit_redeem**](docs/BillingApi.md#ads_credit_redeem) | **POST** /ad_accounts/{ad_account_id}/ads_credit/redeem | Redeem ad credits
*BillingApi* | [**ads_credits_discounts_get**](docs/BillingApi.md#ads_credits_discounts_get) | **GET** /ad_accounts/{ad_account_id}/ads_credit/discounts | Get ads credit discounts
*BillingApi* | [**billing_invoice_download_get**](docs/BillingApi.md#billing_invoice_download_get) | **GET** /ad_accounts/{ad_account_id}/billing_invoice/{billing_invoice_id}/download | Get download url for a billing invoice
*BillingApi* | [**billing_invoices_get**](docs/BillingApi.md#billing_invoices_get) | **GET** /ad_accounts/{ad_account_id}/billing_invoices | Get billing invoices
*BillingApi* | [**billing_profiles_get**](docs/BillingApi.md#billing_profiles_get) | **GET** /ad_accounts/{ad_account_id}/billing_profiles | Get billing profiles
*BillingApi* | [**ssio_accounts_get**](docs/BillingApi.md#ssio_accounts_get) | **GET** /ad_accounts/{ad_account_id}/ssio/accounts | Get Salesforce account details including bill-to information.
*BillingApi* | [**ssio_insertion_order_create**](docs/BillingApi.md#ssio_insertion_order_create) | **POST** /ad_accounts/{ad_account_id}/ssio/insertion_orders | Create insertion order through SSIO.
*BillingApi* | [**ssio_insertion_order_edit**](docs/BillingApi.md#ssio_insertion_order_edit) | **PATCH** /ad_accounts/{ad_account_id}/ssio/insertion_orders | Edit insertion order through SSIO.
*BillingApi* | [**ssio_insertion_orders_status_get_by_ad_account**](docs/BillingApi.md#ssio_insertion_orders_status_get_by_ad_account) | **GET** /ad_accounts/{ad_account_id}/ssio/insertion_orders/status | Get insertion order status by ad account id.
*BillingApi* | [**ssio_insertion_orders_status_get_by_pin_order_id**](docs/BillingApi.md#ssio_insertion_orders_status_get_by_pin_order_id) | **GET** /ad_accounts/{ad_account_id}/ssio/insertion_orders/{pin_order_id}/status | Get insertion order status by pin order id.
*BillingApi* | [**ssio_order_lines_get_by_ad_account**](docs/BillingApi.md#ssio_order_lines_get_by_ad_account) | **GET** /ad_accounts/{ad_account_id}/ssio/order_lines | Get Salesforce order lines by ad account id.
*BoardsApi* | [**board_sections_create**](docs/BoardsApi.md#board_sections_create) | **POST** /boards/{board_id}/sections | Create board section
*BoardsApi* | [**board_sections_delete**](docs/BoardsApi.md#board_sections_delete) | **DELETE** /boards/{board_id}/sections/{section_id} | Delete board section
*BoardsApi* | [**board_sections_list**](docs/BoardsApi.md#board_sections_list) | **GET** /boards/{board_id}/sections | List board sections
*BoardsApi* | [**board_sections_list_pins**](docs/BoardsApi.md#board_sections_list_pins) | **GET** /boards/{board_id}/sections/{section_id}/pins | List Pins on board section
*BoardsApi* | [**board_sections_update**](docs/BoardsApi.md#board_sections_update) | **PATCH** /boards/{board_id}/sections/{section_id} | Update board section
*BoardsApi* | [**boards_create**](docs/BoardsApi.md#boards_create) | **POST** /boards | Create board
*BoardsApi* | [**boards_delete**](docs/BoardsApi.md#boards_delete) | **DELETE** /boards/{board_id} | Delete board
*BoardsApi* | [**boards_get**](docs/BoardsApi.md#boards_get) | **GET** /boards/{board_id} | Get board
*BoardsApi* | [**boards_list**](docs/BoardsApi.md#boards_list) | **GET** /boards | List boards
*BoardsApi* | [**boards_list_pins**](docs/BoardsApi.md#boards_list_pins) | **GET** /boards/{board_id}/pins | List Pins on board
*BoardsApi* | [**boards_update**](docs/BoardsApi.md#boards_update) | **PATCH** /boards/{board_id} | Update board
*BulkApi* | [**bulk_download_create**](docs/BulkApi.md#bulk_download_create) | **POST** /ad_accounts/{ad_account_id}/bulk/download | Get advertiser entities in bulk
*BulkApi* | [**bulk_request_get**](docs/BulkApi.md#bulk_request_get) | **GET** /ad_accounts/{ad_account_id}/bulk/{bulk_request_id} | Download advertiser entities in bulk
*BulkApi* | [**bulk_upsert_create**](docs/BulkApi.md#bulk_upsert_create) | **POST** /ad_accounts/{ad_account_id}/bulk/upsert | Create/update ad entities in bulk
*BusinessAccessAssetsApi* | [**asset_group_create**](docs/BusinessAccessAssetsApi.md#asset_group_create) | **POST** /businesses/{business_id}/asset_groups | Create a new asset group.
*BusinessAccessAssetsApi* | [**asset_group_delete**](docs/BusinessAccessAssetsApi.md#asset_group_delete) | **DELETE** /businesses/{business_id}/asset_groups | Delete asset groups.
*BusinessAccessAssetsApi* | [**asset_group_update**](docs/BusinessAccessAssetsApi.md#asset_group_update) | **PATCH** /businesses/{business_id}/asset_groups | Update asset groups.
*BusinessAccessAssetsApi* | [**business_asset_members_get**](docs/BusinessAccessAssetsApi.md#business_asset_members_get) | **GET** /businesses/{business_id}/assets/{asset_id}/members | Get members with access to asset
*BusinessAccessAssetsApi* | [**business_asset_partners_get**](docs/BusinessAccessAssetsApi.md#business_asset_partners_get) | **GET** /businesses/{business_id}/assets/{asset_id}/partners | Get partners with access to asset
*BusinessAccessAssetsApi* | [**business_assets_get**](docs/BusinessAccessAssetsApi.md#business_assets_get) | **GET** /businesses/{business_id}/assets | List business assets
*BusinessAccessAssetsApi* | [**business_member_assets_get**](docs/BusinessAccessAssetsApi.md#business_member_assets_get) | **GET** /businesses/{business_id}/members/{member_id}/assets | Get assets assigned to a member
*BusinessAccessAssetsApi* | [**business_members_asset_access_delete**](docs/BusinessAccessAssetsApi.md#business_members_asset_access_delete) | **DELETE** /businesses/{business_id}/members/assets/access | Delete member access to asset
*BusinessAccessAssetsApi* | [**business_members_asset_access_update**](docs/BusinessAccessAssetsApi.md#business_members_asset_access_update) | **PATCH** /businesses/{business_id}/members/assets/access | Assign/Update member asset permissions
*BusinessAccessAssetsApi* | [**business_partner_asset_access_get**](docs/BusinessAccessAssetsApi.md#business_partner_asset_access_get) | **GET** /businesses/{business_id}/partners/{partner_id}/assets | Get assets assigned to a partner or assets assigned by a partner
*BusinessAccessAssetsApi* | [**delete_partner_asset_access_handler_impl**](docs/BusinessAccessAssetsApi.md#delete_partner_asset_access_handler_impl) | **DELETE** /businesses/{business_id}/partners/assets | Delete partner access to asset
*BusinessAccessAssetsApi* | [**update_partner_asset_access_handler_impl**](docs/BusinessAccessAssetsApi.md#update_partner_asset_access_handler_impl) | **PATCH** /businesses/{business_id}/partners/assets | Assign/Update partner asset permissions
*BusinessAccessInviteApi* | [**asset_access_requests_create**](docs/BusinessAccessInviteApi.md#asset_access_requests_create) | **POST** /businesses/{business_id}/requests/assets/access | Create a request to access an existing partner&#39;s assets.
*BusinessAccessInviteApi* | [**cancel_invites_or_requests**](docs/BusinessAccessInviteApi.md#cancel_invites_or_requests) | **DELETE** /businesses/{business_id}/invites | Cancel invites/requests
*BusinessAccessInviteApi* | [**create_asset_invites**](docs/BusinessAccessInviteApi.md#create_asset_invites) | **POST** /businesses/{business_id}/invites/assets/access | Update invite/request with an asset permission
*BusinessAccessInviteApi* | [**create_membership_or_partnership_invites**](docs/BusinessAccessInviteApi.md#create_membership_or_partnership_invites) | **POST** /businesses/{business_id}/invites | Create invites or requests
*BusinessAccessInviteApi* | [**get_invites**](docs/BusinessAccessInviteApi.md#get_invites) | **GET** /businesses/{business_id}/invites | Get invites/requests
*BusinessAccessInviteApi* | [**respond_business_access_invites**](docs/BusinessAccessInviteApi.md#respond_business_access_invites) | **PATCH** /businesses/invites | Accept or decline an invite/request
*BusinessAccessRelationshipsApi* | [**brand_accounts_create**](docs/BusinessAccessRelationshipsApi.md#brand_accounts_create) | **POST** /business_access/business_hierarchy/{business_hierarchy_id}/brand_accounts | Create a Brand Account
*BusinessAccessRelationshipsApi* | [**brand_accounts_update**](docs/BusinessAccessRelationshipsApi.md#brand_accounts_update) | **PATCH** /business_access/business_hierarchy/{business_hierarchy_id}/brand_accounts/{brand_account_id} | Update a Brand Account
*BusinessAccessRelationshipsApi* | [**delete_business_membership**](docs/BusinessAccessRelationshipsApi.md#delete_business_membership) | **DELETE** /businesses/{business_id}/members | Terminate business memberships
*BusinessAccessRelationshipsApi* | [**delete_business_partners**](docs/BusinessAccessRelationshipsApi.md#delete_business_partners) | **DELETE** /businesses/{business_id}/partners | Terminate business partnerships
*BusinessAccessRelationshipsApi* | [**get_business_employers**](docs/BusinessAccessRelationshipsApi.md#get_business_employers) | **GET** /businesses/employers | List business employers for user
*BusinessAccessRelationshipsApi* | [**get_business_members**](docs/BusinessAccessRelationshipsApi.md#get_business_members) | **GET** /businesses/{business_id}/members | Get business members
*BusinessAccessRelationshipsApi* | [**get_business_partners**](docs/BusinessAccessRelationshipsApi.md#get_business_partners) | **GET** /businesses/{business_id}/partners | Get business partners
*BusinessAccessRelationshipsApi* | [**system_user_update**](docs/BusinessAccessRelationshipsApi.md#system_user_update) | **PATCH** /businesses/{business_id}/system_users/{system_user_id} | Update a system user information.
*BusinessAccessRelationshipsApi* | [**update_business_memberships**](docs/BusinessAccessRelationshipsApi.md#update_business_memberships) | **PATCH** /businesses/{business_id}/members | Update member&#39;s business role
*CampaignsApi* | [**ad_pins_analytics**](docs/CampaignsApi.md#ad_pins_analytics) | **GET** /ad_accounts/{ad_account_id}/pins/analytics | Get pins analytics
*CampaignsApi* | [**campaign_targeting_analytics_get**](docs/CampaignsApi.md#campaign_targeting_analytics_get) | **GET** /ad_accounts/{ad_account_id}/campaigns/targeting_analytics | Get targeting analytics for campaigns
*CampaignsApi* | [**campaigns_analytics**](docs/CampaignsApi.md#campaigns_analytics) | **GET** /ad_accounts/{ad_account_id}/campaigns/analytics | Get campaign analytics
*CampaignsApi* | [**campaigns_create**](docs/CampaignsApi.md#campaigns_create) | **POST** /ad_accounts/{ad_account_id}/campaigns | Create campaigns
*CampaignsApi* | [**campaigns_get**](docs/CampaignsApi.md#campaigns_get) | **GET** /ad_accounts/{ad_account_id}/campaigns/{campaign_id} | Get campaign
*CampaignsApi* | [**campaigns_list**](docs/CampaignsApi.md#campaigns_list) | **GET** /ad_accounts/{ad_account_id}/campaigns | List campaigns
*CampaignsApi* | [**campaigns_update**](docs/CampaignsApi.md#campaigns_update) | **PATCH** /ad_accounts/{ad_account_id}/campaigns | Update campaigns
*CatalogFeedsApi* | [**feed_processing_results_list**](docs/CatalogFeedsApi.md#feed_processing_results_list) | **GET** /catalogs/feeds/{feed_id}/processing_results | List feed processing results
*CatalogFeedsApi* | [**feeds_create**](docs/CatalogFeedsApi.md#feeds_create) | **POST** /catalogs/feeds | Create feed
*CatalogFeedsApi* | [**feeds_delete**](docs/CatalogFeedsApi.md#feeds_delete) | **DELETE** /catalogs/feeds/{feed_id} | Delete feed
*CatalogFeedsApi* | [**feeds_get**](docs/CatalogFeedsApi.md#feeds_get) | **GET** /catalogs/feeds/{feed_id} | Get feed
*CatalogFeedsApi* | [**feeds_ingest**](docs/CatalogFeedsApi.md#feeds_ingest) | **POST** /catalogs/feeds/{feed_id}/ingest | Ingest feed items
*CatalogFeedsApi* | [**feeds_list**](docs/CatalogFeedsApi.md#feeds_list) | **GET** /catalogs/feeds | List feeds
*CatalogFeedsApi* | [**feeds_update**](docs/CatalogFeedsApi.md#feeds_update) | **PATCH** /catalogs/feeds/{feed_id} | Update feed
*CatalogFeedsApi* | [**items_issues_list**](docs/CatalogFeedsApi.md#items_issues_list) | **GET** /catalogs/processing_results/{processing_result_id}/item_issues | List item issues
*CatalogItemsApi* | [**items_batch_get**](docs/CatalogItemsApi.md#items_batch_get) | **GET** /catalogs/items/batch/{batch_id} | Get item batch status
*CatalogItemsApi* | [**items_batch_post**](docs/CatalogItemsApi.md#items_batch_post) | **POST** /catalogs/items/batch | Operate on item batch
*CatalogItemsApi* | [**items_post**](docs/CatalogItemsApi.md#items_post) | **POST** /catalogs/items | Get catalogs items (POST)
*CatalogProductGroupsApi* | [**catalogs_product_group_pins_list**](docs/CatalogProductGroupsApi.md#catalogs_product_group_pins_list) | **GET** /catalogs/product_groups/{product_group_id}/products | List products by product group
*CatalogProductGroupsApi* | [**catalogs_product_groups_create**](docs/CatalogProductGroupsApi.md#catalogs_product_groups_create) | **POST** /catalogs/product_groups | Create product group
*CatalogProductGroupsApi* | [**catalogs_product_groups_create_many**](docs/CatalogProductGroupsApi.md#catalogs_product_groups_create_many) | **POST** /catalogs/product_groups/multiple | Create product groups
*CatalogProductGroupsApi* | [**catalogs_product_groups_delete**](docs/CatalogProductGroupsApi.md#catalogs_product_groups_delete) | **DELETE** /catalogs/product_groups/{product_group_id} | Delete product group
*CatalogProductGroupsApi* | [**catalogs_product_groups_delete_many**](docs/CatalogProductGroupsApi.md#catalogs_product_groups_delete_many) | **DELETE** /catalogs/product_groups/multiple | Delete product groups
*CatalogProductGroupsApi* | [**catalogs_product_groups_get**](docs/CatalogProductGroupsApi.md#catalogs_product_groups_get) | **GET** /catalogs/product_groups/{product_group_id} | Get product group
*CatalogProductGroupsApi* | [**catalogs_product_groups_list**](docs/CatalogProductGroupsApi.md#catalogs_product_groups_list) | **GET** /catalogs/product_groups | List product groups
*CatalogProductGroupsApi* | [**catalogs_product_groups_product_counts_get**](docs/CatalogProductGroupsApi.md#catalogs_product_groups_product_counts_get) | **GET** /catalogs/product_groups/{product_group_id}/product_counts | Get product counts
*CatalogProductGroupsApi* | [**catalogs_product_groups_update**](docs/CatalogProductGroupsApi.md#catalogs_product_groups_update) | **PATCH** /catalogs/product_groups/{product_group_id} | Update single product group
*CatalogProductGroupsApi* | [**products_by_product_group_filter_list**](docs/CatalogProductGroupsApi.md#products_by_product_group_filter_list) | **POST** /catalogs/products/get_by_product_group_filters | List products by filter
*CatalogReportsApi* | [**reports_create**](docs/CatalogReportsApi.md#reports_create) | **POST** /catalogs/reports | Build catalogs report
*CatalogReportsApi* | [**reports_get**](docs/CatalogReportsApi.md#reports_get) | **GET** /catalogs/reports | Get catalogs report
*CatalogReportsApi* | [**reports_stats**](docs/CatalogReportsApi.md#reports_stats) | **GET** /catalogs/reports/stats | List report stats
*CatalogsApi* | [**catalogs_available_filter_values**](docs/CatalogsApi.md#catalogs_available_filter_values) | **GET** /catalogs/available_filter_values | List available filter values
*CatalogsApi* | [**catalogs_create**](docs/CatalogsApi.md#catalogs_create) | **POST** /catalogs | Create catalog
*CatalogsApi* | [**catalogs_list**](docs/CatalogsApi.md#catalogs_list) | **GET** /catalogs | List catalogs
*ConversionEqsApi* | [**conversion_eqs_list**](docs/ConversionEqsApi.md#conversion_eqs_list) | **GET** /ad_accounts/{ad_account_id}/conversion_eqs | Get event quality score (EQS)
*ConversionEventsApi* | [**events_create**](docs/ConversionEventsApi.md#events_create) | **POST** /ad_accounts/{ad_account_id}/events | Send conversions
*ConversionTagsApi* | [**conversion_tags_create**](docs/ConversionTagsApi.md#conversion_tags_create) | **POST** /ad_accounts/{ad_account_id}/conversion_tags | Create conversion tag
*ConversionTagsApi* | [**conversion_tags_get**](docs/ConversionTagsApi.md#conversion_tags_get) | **GET** /ad_accounts/{ad_account_id}/conversion_tags/{conversion_tag_id} | Get conversion tag
*ConversionTagsApi* | [**conversion_tags_list**](docs/ConversionTagsApi.md#conversion_tags_list) | **GET** /ad_accounts/{ad_account_id}/conversion_tags | List conversion tags
*ConversionTagsApi* | [**ocpm_eligible_conversion_tags_get**](docs/ConversionTagsApi.md#ocpm_eligible_conversion_tags_get) | **GET** /ad_accounts/{ad_account_id}/conversion_tags/ocpm_eligible | Get Ocpm eligible conversion tags
*ConversionTagsApi* | [**page_visit_conversion_tags_get**](docs/ConversionTagsApi.md#page_visit_conversion_tags_get) | **GET** /ad_accounts/{ad_account_id}/conversion_tags/page_visit | Get page visit conversion tags
*ConversionsApi* | [**advertiser_defined_events_get**](docs/ConversionsApi.md#advertiser_defined_events_get) | **GET** /ad_accounts/{ad_account_id}/advertiser_defined_events | Get advertiser defined events
*CustomerListUploadsApi* | [**customer_list_uploads_create**](docs/CustomerListUploadsApi.md#customer_list_uploads_create) | **POST** /ad_accounts/{ad_account_id}/customer_lists/{customer_list_id}/uploads | Create customer list upload
*CustomerListUploadsApi* | [**customer_list_uploads_get**](docs/CustomerListUploadsApi.md#customer_list_uploads_get) | **GET** /ad_accounts/{ad_account_id}/customer_lists/{customer_list_id}/uploads/{customer_list_upload_id} | Get customer list upload
*CustomerListUploadsApi* | [**customer_list_uploads_run**](docs/CustomerListUploadsApi.md#customer_list_uploads_run) | **POST** /ad_accounts/{ad_account_id}/customer_lists/{customer_list_id}/uploads/{customer_list_upload_id}/run | Run customer list upload
*CustomerListsApi* | [**customer_lists_create**](docs/CustomerListsApi.md#customer_lists_create) | **POST** /ad_accounts/{ad_account_id}/customer_lists | Create customer lists
*CustomerListsApi* | [**customer_lists_get**](docs/CustomerListsApi.md#customer_lists_get) | **GET** /ad_accounts/{ad_account_id}/customer_lists/{customer_list_id} | Get customer list
*CustomerListsApi* | [**customer_lists_list**](docs/CustomerListsApi.md#customer_lists_list) | **GET** /ad_accounts/{ad_account_id}/customer_lists | Get customer lists
*CustomerListsApi* | [**customer_lists_update**](docs/CustomerListsApi.md#customer_lists_update) | **PATCH** /ad_accounts/{ad_account_id}/customer_lists/{customer_list_id} | Update customer list
*IntegrationsApi* | [**integrations_commerce_del**](docs/IntegrationsApi.md#integrations_commerce_del) | **DELETE** /integrations/commerce/{external_business_id} | Delete commerce integration
*IntegrationsApi* | [**integrations_commerce_get**](docs/IntegrationsApi.md#integrations_commerce_get) | **GET** /integrations/commerce/{external_business_id} | Get commerce integration
*IntegrationsApi* | [**integrations_commerce_patch**](docs/IntegrationsApi.md#integrations_commerce_patch) | **PATCH** /integrations/commerce/{external_business_id} | Update commerce integration
*IntegrationsApi* | [**integrations_commerce_post**](docs/IntegrationsApi.md#integrations_commerce_post) | **POST** /integrations/commerce | Create commerce integration
*IntegrationsApi* | [**integrations_get_by_id**](docs/IntegrationsApi.md#integrations_get_by_id) | **GET** /integrations/{id} | Get integration metadata
*IntegrationsApi* | [**integrations_get_list**](docs/IntegrationsApi.md#integrations_get_list) | **GET** /integrations | Get integration metadata list
*IntegrationsApi* | [**integrations_logs_post**](docs/IntegrationsApi.md#integrations_logs_post) | **POST** /integrations/logs | Receives batched logs from integration applications.
*KeywordsApi* | [**country_keywords_metrics_get**](docs/KeywordsApi.md#country_keywords_metrics_get) | **GET** /ad_accounts/{ad_account_id}/keywords/metrics | Get country&#39;s keyword metrics
*KeywordsApi* | [**keywords_create**](docs/KeywordsApi.md#keywords_create) | **POST** /ad_accounts/{ad_account_id}/keywords | Create keywords
*KeywordsApi* | [**keywords_get**](docs/KeywordsApi.md#keywords_get) | **GET** /ad_accounts/{ad_account_id}/keywords | Get keywords
*KeywordsApi* | [**keywords_update**](docs/KeywordsApi.md#keywords_update) | **PATCH** /ad_accounts/{ad_account_id}/keywords | Update keywords
*KeywordsApi* | [**trending_keywords_list**](docs/KeywordsApi.md#trending_keywords_list) | **GET** /trends/keywords/{region}/top/{trend_type} | List trending keywords
*LabelsApi* | [**labels_create**](docs/LabelsApi.md#labels_create) | **POST** /ad_accounts/{ad_account_id}/labels | Create labels
*LabelsApi* | [**labels_list**](docs/LabelsApi.md#labels_list) | **GET** /ad_accounts/{ad_account_id}/labels | List labels
*LabelsApi* | [**labels_update**](docs/LabelsApi.md#labels_update) | **PATCH** /ad_accounts/{ad_account_id}/labels | Update labels
*LeadAdsApi* | [**ad_accounts_subscriptions_del_by_id**](docs/LeadAdsApi.md#ad_accounts_subscriptions_del_by_id) | **DELETE** /ad_accounts/{ad_account_id}/leads/subscriptions/{subscription_id} | Delete lead ads subscription
*LeadAdsApi* | [**ad_accounts_subscriptions_get_by_id**](docs/LeadAdsApi.md#ad_accounts_subscriptions_get_by_id) | **GET** /ad_accounts/{ad_account_id}/leads/subscriptions/{subscription_id} | Get lead ads subscription by ID
*LeadAdsApi* | [**ad_accounts_subscriptions_get_list**](docs/LeadAdsApi.md#ad_accounts_subscriptions_get_list) | **GET** /ad_accounts/{ad_account_id}/leads/subscriptions | Get lead ads subscriptions
*LeadAdsApi* | [**ad_accounts_subscriptions_post**](docs/LeadAdsApi.md#ad_accounts_subscriptions_post) | **POST** /ad_accounts/{ad_account_id}/leads/subscriptions | Create lead ads subscription
*LeadFormsApi* | [**lead_form_get**](docs/LeadFormsApi.md#lead_form_get) | **GET** /ad_accounts/{ad_account_id}/lead_forms/{lead_form_id} | Get lead form by id
*LeadFormsApi* | [**lead_form_test_create**](docs/LeadFormsApi.md#lead_form_test_create) | **POST** /ad_accounts/{ad_account_id}/lead_forms/{lead_form_id}/test | Create lead form test data
*LeadFormsApi* | [**lead_forms_create**](docs/LeadFormsApi.md#lead_forms_create) | **POST** /ad_accounts/{ad_account_id}/lead_forms | Create lead forms
*LeadFormsApi* | [**lead_forms_list**](docs/LeadFormsApi.md#lead_forms_list) | **GET** /ad_accounts/{ad_account_id}/lead_forms | List lead forms
*LeadFormsApi* | [**lead_forms_update**](docs/LeadFormsApi.md#lead_forms_update) | **PATCH** /ad_accounts/{ad_account_id}/lead_forms | Update lead forms
*LeadsExportApi* | [**leads_export_create**](docs/LeadsExportApi.md#leads_export_create) | **POST** /ad_accounts/{ad_account_id}/leads_export | Create a request to export leads collected from a lead ad
*LeadsExportApi* | [**leads_export_get**](docs/LeadsExportApi.md#leads_export_get) | **GET** /ad_accounts/{ad_account_id}/leads_export/{leads_export_id} | Get the lead export from the lead export create call
*MediaApi* | [**media_create**](docs/MediaApi.md#media_create) | **POST** /media | Register media upload
*MediaApi* | [**media_get**](docs/MediaApi.md#media_get) | **GET** /media/{media_id} | Get media upload details
*MediaApi* | [**media_list**](docs/MediaApi.md#media_list) | **GET** /media | List media uploads
*MsotEventsApi* | [**msot_events_create**](docs/MsotEventsApi.md#msot_events_create) | **POST** /ad_accounts/{ad_account_id}/msot/events | Send Measurement Source Of Truth (MSOT) attributed conversion events
*NotificationApi* | [**notification_post**](docs/NotificationApi.md#notification_post) | **POST** /notifications | Receive notifications from external partners.
*OauthApi* | [**oauth_conversion_token**](docs/OauthApi.md#oauth_conversion_token) | **POST** /oauth/conversion_token | Generate OAuth access token for conversion API
*OauthApi* | [**oauth_token**](docs/OauthApi.md#oauth_token) | **POST** /oauth/token | Generate OAuth access token
*OauthApi* | [**token_revoke**](docs/OauthApi.md#token_revoke) | **POST** /oauth/token/revoke | Revoke a token
*OrderLinesApi* | [**order_lines_get**](docs/OrderLinesApi.md#order_lines_get) | **GET** /ad_accounts/{ad_account_id}/order_lines/{order_line_id} | Get order line
*OrderLinesApi* | [**order_lines_list**](docs/OrderLinesApi.md#order_lines_list) | **GET** /ad_accounts/{ad_account_id}/order_lines | Get order lines
*PinsApi* | [**multi_pins_analytics**](docs/PinsApi.md#multi_pins_analytics) | **GET** /pins/analytics | Get multiple Pin analytics
*PinsApi* | [**pins_analytics**](docs/PinsApi.md#pins_analytics) | **GET** /pins/{pin_id}/analytics | Get Pin analytics
*PinsApi* | [**pins_create**](docs/PinsApi.md#pins_create) | **POST** /pins | Create Pin
*PinsApi* | [**pins_delete**](docs/PinsApi.md#pins_delete) | **DELETE** /pins/{pin_id} | Delete Pin
*PinsApi* | [**pins_get**](docs/PinsApi.md#pins_get) | **GET** /pins/{pin_id} | Get Pin
*PinsApi* | [**pins_list**](docs/PinsApi.md#pins_list) | **GET** /pins | List Pins
*PinsApi* | [**pins_save**](docs/PinsApi.md#pins_save) | **POST** /pins/{pin_id}/save | Save Pin
*PinsApi* | [**pins_update**](docs/PinsApi.md#pins_update) | **PATCH** /pins/{pin_id} | Update Pin
*ProductCategoriesApi* | [**trends_featured_topics_list**](docs/ProductCategoriesApi.md#trends_featured_topics_list) | **GET** /trends/topics/featured | Get featured topics
*ProductCategoriesApi* | [**trends_product_categories_details_list**](docs/ProductCategoriesApi.md#trends_product_categories_details_list) | **GET** /trends/product_categories/details | Get product category details
*ProductCategoriesApi* | [**trends_product_categories_trending_list**](docs/ProductCategoriesApi.md#trends_product_categories_trending_list) | **GET** /trends/product_categories/trending | Get a list of growing Shopping Product Categories
*ProductGroupPromotionsApi* | [**product_group_promotions_create**](docs/ProductGroupPromotionsApi.md#product_group_promotions_create) | **POST** /ad_accounts/{ad_account_id}/product_group_promotions | Create product group promotions
*ProductGroupPromotionsApi* | [**product_group_promotions_get**](docs/ProductGroupPromotionsApi.md#product_group_promotions_get) | **GET** /ad_accounts/{ad_account_id}/product_group_promotions/{product_group_promotion_id} | Get a product group promotion by id
*ProductGroupPromotionsApi* | [**product_group_promotions_list**](docs/ProductGroupPromotionsApi.md#product_group_promotions_list) | **GET** /ad_accounts/{ad_account_id}/product_group_promotions | Get product group promotions
*ProductGroupPromotionsApi* | [**product_group_promotions_update**](docs/ProductGroupPromotionsApi.md#product_group_promotions_update) | **PATCH** /ad_accounts/{ad_account_id}/product_group_promotions | Update product group promotions
*ProductGroupPromotionsApi* | [**product_groups_analytics**](docs/ProductGroupPromotionsApi.md#product_groups_analytics) | **GET** /ad_accounts/{ad_account_id}/product_groups/analytics | Get product group analytics
*PromotionsApi* | [**promotions_create**](docs/PromotionsApi.md#promotions_create) | **POST** /ad_accounts/{ad_account_id}/promotions | Create promotions
*PromotionsApi* | [**promotions_delete**](docs/PromotionsApi.md#promotions_delete) | **DELETE** /ad_accounts/{ad_account_id}/promotions/{promotion_id} | Delete promotion by id
*PromotionsApi* | [**promotions_get**](docs/PromotionsApi.md#promotions_get) | **GET** /ad_accounts/{ad_account_id}/promotions/{promotion_id} | Get promotion by id
*PromotionsApi* | [**promotions_list**](docs/PromotionsApi.md#promotions_list) | **GET** /ad_accounts/{ad_account_id}/promotions | Get promotions
*PromotionsApi* | [**promotions_update**](docs/PromotionsApi.md#promotions_update) | **PATCH** /ad_accounts/{ad_account_id}/promotions | Update promotions
*ResourcesApi* | [**ad_account_countries_get**](docs/ResourcesApi.md#ad_account_countries_get) | **GET** /resources/ad_account_countries | Get ad accounts countries
*ResourcesApi* | [**delivery_metrics_get**](docs/ResourcesApi.md#delivery_metrics_get) | **GET** /resources/delivery_metrics | Get available metrics&#39; definitions
*ResourcesApi* | [**interest_targeting_options_get**](docs/ResourcesApi.md#interest_targeting_options_get) | **GET** /resources/targeting/interests/{interest_id} | Get interest details
*ResourcesApi* | [**lead_form_questions_get**](docs/ResourcesApi.md#lead_form_questions_get) | **GET** /resources/lead_form_questions | Get lead form questions
*ResourcesApi* | [**metrics_ready_state_get**](docs/ResourcesApi.md#metrics_ready_state_get) | **GET** /resources/metrics_ready_state | Get metrics ready state
*ResourcesApi* | [**targeting_options_get**](docs/ResourcesApi.md#targeting_options_get) | **GET** /resources/targeting/{targeting_type} | Get targeting options
*SearchApi* | [**search_partner_pins**](docs/SearchApi.md#search_partner_pins) | **GET** /search/partner/pins | Search pins by a given search term
*SearchApi* | [**search_user_boards_get**](docs/SearchApi.md#search_user_boards_get) | **GET** /search/boards | Search user&#39;s boards
*SearchApi* | [**search_user_pins_list**](docs/SearchApi.md#search_user_pins_list) | **GET** /search/pins | Search user&#39;s Pins
*TargetingTemplateApi* | [**targeting_template_create**](docs/TargetingTemplateApi.md#targeting_template_create) | **POST** /ad_accounts/{ad_account_id}/targeting_templates | Create targeting templates
*TargetingTemplateApi* | [**targeting_template_list**](docs/TargetingTemplateApi.md#targeting_template_list) | **GET** /ad_accounts/{ad_account_id}/targeting_templates | List targeting templates
*TargetingTemplateApi* | [**targeting_template_update**](docs/TargetingTemplateApi.md#targeting_template_update) | **PATCH** /ad_accounts/{ad_account_id}/targeting_templates | Update targeting templates
*TermsApi* | [**terms_related_list**](docs/TermsApi.md#terms_related_list) | **GET** /terms/related | List related terms
*TermsApi* | [**terms_suggested_list**](docs/TermsApi.md#terms_suggested_list) | **GET** /terms/suggested | List suggested terms
*TermsOfServiceApi* | [**terms_of_service_get**](docs/TermsOfServiceApi.md#terms_of_service_get) | **GET** /ad_accounts/{ad_account_id}/terms_of_service | Get terms of service
*UserAccountApi* | [**boards_user_follows_list**](docs/UserAccountApi.md#boards_user_follows_list) | **GET** /user_account/following/boards | List following boards
*UserAccountApi* | [**follow_user_update**](docs/UserAccountApi.md#follow_user_update) | **POST** /user_account/following/{username} | Follow user
*UserAccountApi* | [**followers_list**](docs/UserAccountApi.md#followers_list) | **GET** /user_account/followers | List followers
*UserAccountApi* | [**linked_business_accounts_get**](docs/UserAccountApi.md#linked_business_accounts_get) | **GET** /user_account/businesses | List linked businesses
*UserAccountApi* | [**unverify_website_delete**](docs/UserAccountApi.md#unverify_website_delete) | **DELETE** /user_account/websites | Unverify website
*UserAccountApi* | [**user_account_analytics**](docs/UserAccountApi.md#user_account_analytics) | **GET** /user_account/analytics | Get user account analytics
*UserAccountApi* | [**user_account_analytics_top_pins**](docs/UserAccountApi.md#user_account_analytics_top_pins) | **GET** /user_account/analytics/top_pins | Get user account top pins analytics
*UserAccountApi* | [**user_account_analytics_top_video_pins**](docs/UserAccountApi.md#user_account_analytics_top_video_pins) | **GET** /user_account/analytics/top_video_pins | Get user account top video pins analytics
*UserAccountApi* | [**user_account_followed_interests**](docs/UserAccountApi.md#user_account_followed_interests) | **GET** /users/{username}/interests/follow | List following interests
*UserAccountApi* | [**user_account_get**](docs/UserAccountApi.md#user_account_get) | **GET** /user_account | Get user account
*UserAccountApi* | [**user_following_get**](docs/UserAccountApi.md#user_following_get) | **GET** /user_account/following | List following
*UserAccountApi* | [**user_websites_get**](docs/UserAccountApi.md#user_websites_get) | **GET** /user_account/websites | Get user websites
*UserAccountApi* | [**verify_website_update**](docs/UserAccountApi.md#verify_website_update) | **POST** /user_account/websites | Verify website
*UserAccountApi* | [**website_verification_get**](docs/UserAccountApi.md#website_verification_get) | **GET** /user_account/websites/verification | Get user verification code for website claiming


## Documentation For Models

 - [Account](docs/Account.md)
 - [ActionType](docs/ActionType.md)
 - [AdAccount](docs/AdAccount.md)
 - [AdAccountAnalyticsResponseInner](docs/AdAccountAnalyticsResponseInner.md)
 - [AdAccountCreate](docs/AdAccountCreate.md)
 - [AdAccountCreateSubscriptionRequest](docs/AdAccountCreateSubscriptionRequest.md)
 - [AdAccountCreateSubscriptionRequestPartnerMetadata](docs/AdAccountCreateSubscriptionRequestPartnerMetadata.md)
 - [AdAccountCreateSubscriptionResponse](docs/AdAccountCreateSubscriptionResponse.md)
 - [AdAccountGetSubscriptionResponse](docs/AdAccountGetSubscriptionResponse.md)
 - [AdAccountOwner](docs/AdAccountOwner.md)
 - [AdAccountsAudiencesSharedAccountsList200Response](docs/AdAccountsAudiencesSharedAccountsList200Response.md)
 - [AdAccountsCountryResponse](docs/AdAccountsCountryResponse.md)
 - [AdAccountsCountryResponseData](docs/AdAccountsCountryResponseData.md)
 - [AdAccountsList200Response](docs/AdAccountsList200Response.md)
 - [AdAccountsSubscriptionsGetList200Response](docs/AdAccountsSubscriptionsGetList200Response.md)
 - [AdArrayResponse](docs/AdArrayResponse.md)
 - [AdArrayResponseElement](docs/AdArrayResponseElement.md)
 - [AdCommon](docs/AdCommon.md)
 - [AdCountry](docs/AdCountry.md)
 - [AdCreateRequest](docs/AdCreateRequest.md)
 - [AdGroupArrayResponse](docs/AdGroupArrayResponse.md)
 - [AdGroupArrayResponseElement](docs/AdGroupArrayResponseElement.md)
 - [AdGroupAudienceSizingRequest](docs/AdGroupAudienceSizingRequest.md)
 - [AdGroupAudienceSizingRequestKeywordsInner](docs/AdGroupAudienceSizingRequestKeywordsInner.md)
 - [AdGroupAudienceSizingResponse](docs/AdGroupAudienceSizingResponse.md)
 - [AdGroupCommon](docs/AdGroupCommon.md)
 - [AdGroupCreateRequest](docs/AdGroupCreateRequest.md)
 - [AdGroupIdFilter](docs/AdGroupIdFilter.md)
 - [AdGroupResponse](docs/AdGroupResponse.md)
 - [AdGroupSummaryStatus](docs/AdGroupSummaryStatus.md)
 - [AdGroupUpdateRequest](docs/AdGroupUpdateRequest.md)
 - [AdGroupsAnalyticsResponseInner](docs/AdGroupsAnalyticsResponseInner.md)
 - [AdGroupsList200Response](docs/AdGroupsList200Response.md)
 - [AdPinAnalytics](docs/AdPinAnalytics.md)
 - [AdPinId](docs/AdPinId.md)
 - [AdPreviewCreateFromImage](docs/AdPreviewCreateFromImage.md)
 - [AdPreviewCreateFromPin](docs/AdPreviewCreateFromPin.md)
 - [AdPreviewRequest](docs/AdPreviewRequest.md)
 - [AdPreviewShopping](docs/AdPreviewShopping.md)
 - [AdPreviewURLResponse](docs/AdPreviewURLResponse.md)
 - [AdResponse](docs/AdResponse.md)
 - [AdUpdateRequest](docs/AdUpdateRequest.md)
 - [AdsAnalyticsAdGroupTargetingType](docs/AdsAnalyticsAdGroupTargetingType.md)
 - [AdsAnalyticsAdTargetingType](docs/AdsAnalyticsAdTargetingType.md)
 - [AdsAnalyticsCampaignTargetingType](docs/AdsAnalyticsCampaignTargetingType.md)
 - [AdsAnalyticsCreateAsyncRequest](docs/AdsAnalyticsCreateAsyncRequest.md)
 - [AdsAnalyticsCreateAsyncRequestAllOfCustomConversionEventMetrics](docs/AdsAnalyticsCreateAsyncRequestAllOfCustomConversionEventMetrics.md)
 - [AdsAnalyticsCreateAsyncResponse](docs/AdsAnalyticsCreateAsyncResponse.md)
 - [AdsAnalyticsFilterColumn](docs/AdsAnalyticsFilterColumn.md)
 - [AdsAnalyticsFilterOperator](docs/AdsAnalyticsFilterOperator.md)
 - [AdsAnalyticsGetAsyncResponse](docs/AdsAnalyticsGetAsyncResponse.md)
 - [AdsAnalyticsMetricsFilter](docs/AdsAnalyticsMetricsFilter.md)
 - [AdsAnalyticsResponseInner](docs/AdsAnalyticsResponseInner.md)
 - [AdsAnalyticsTargetingType](docs/AdsAnalyticsTargetingType.md)
 - [AdsCreditDiscountsResponse](docs/AdsCreditDiscountsResponse.md)
 - [AdsCreditRedeemRequest](docs/AdsCreditRedeemRequest.md)
 - [AdsCreditRedeemResponse](docs/AdsCreditRedeemResponse.md)
 - [AdsCreditsDiscountsGet200Response](docs/AdsCreditsDiscountsGet200Response.md)
 - [AdsList200Response](docs/AdsList200Response.md)
 - [AdvancedAuctionBidOptions](docs/AdvancedAuctionBidOptions.md)
 - [AdvancedAuctionItem](docs/AdvancedAuctionItem.md)
 - [AdvancedAuctionItems](docs/AdvancedAuctionItems.md)
 - [AdvancedAuctionItemsGetRecord](docs/AdvancedAuctionItemsGetRecord.md)
 - [AdvancedAuctionItemsGetRequest](docs/AdvancedAuctionItemsGetRequest.md)
 - [AdvancedAuctionItemsSubmitDeleteRecord](docs/AdvancedAuctionItemsSubmitDeleteRecord.md)
 - [AdvancedAuctionItemsSubmitRecord](docs/AdvancedAuctionItemsSubmitRecord.md)
 - [AdvancedAuctionItemsSubmitRequest](docs/AdvancedAuctionItemsSubmitRequest.md)
 - [AdvancedAuctionItemsSubmitUpsertRecord](docs/AdvancedAuctionItemsSubmitUpsertRecord.md)
 - [AdvancedAuctionKey](docs/AdvancedAuctionKey.md)
 - [AdvancedAuctionOperation](docs/AdvancedAuctionOperation.md)
 - [AdvancedAuctionOperationError](docs/AdvancedAuctionOperationError.md)
 - [AdvancedAuctionProcessedItems](docs/AdvancedAuctionProcessedItems.md)
 - [AdvertiserDefinedEvent](docs/AdvertiserDefinedEvent.md)
 - [AdvertiserDefinedEventsResponse](docs/AdvertiserDefinedEventsResponse.md)
 - [AgeTrendsBucket](docs/AgeTrendsBucket.md)
 - [AllOf](docs/AllOf.md)
 - [AmazonConnectRequest](docs/AmazonConnectRequest.md)
 - [AnalyticsDailyMetrics](docs/AnalyticsDailyMetrics.md)
 - [AnalyticsMetricsResponse](docs/AnalyticsMetricsResponse.md)
 - [AnyOf](docs/AnyOf.md)
 - [AppTypeMultipliers](docs/AppTypeMultipliers.md)
 - [AssetGroupBinding](docs/AssetGroupBinding.md)
 - [AssetGroupType](docs/AssetGroupType.md)
 - [AssetIdPermissions](docs/AssetIdPermissions.md)
 - [Audience](docs/Audience.md)
 - [AudienceAccountType](docs/AudienceAccountType.md)
 - [AudienceCategory](docs/AudienceCategory.md)
 - [AudienceCommon](docs/AudienceCommon.md)
 - [AudienceCreateRequest](docs/AudienceCreateRequest.md)
 - [AudienceDefinition](docs/AudienceDefinition.md)
 - [AudienceDefinitionResponse](docs/AudienceDefinitionResponse.md)
 - [AudienceDefinitionScope](docs/AudienceDefinitionScope.md)
 - [AudienceDefinitionType](docs/AudienceDefinitionType.md)
 - [AudienceDemographicValue](docs/AudienceDemographicValue.md)
 - [AudienceDemographics](docs/AudienceDemographics.md)
 - [AudienceInsightCategoryArrayResponse](docs/AudienceInsightCategoryArrayResponse.md)
 - [AudienceInsightCategoryCommon](docs/AudienceInsightCategoryCommon.md)
 - [AudienceInsightType](docs/AudienceInsightType.md)
 - [AudienceInsightsResponse](docs/AudienceInsightsResponse.md)
 - [AudienceRule](docs/AudienceRule.md)
 - [AudienceShareType](docs/AudienceShareType.md)
 - [AudienceSubcategory](docs/AudienceSubcategory.md)
 - [AudienceType](docs/AudienceType.md)
 - [AudienceUpdateOperationType](docs/AudienceUpdateOperationType.md)
 - [AudienceUpdateRequest](docs/AudienceUpdateRequest.md)
 - [AudiencesList200Response](docs/AudiencesList200Response.md)
 - [AuthRespondInvitesBody](docs/AuthRespondInvitesBody.md)
 - [AuthRespondInvitesBodyInvitesInner](docs/AuthRespondInvitesBodyInvitesInner.md)
 - [AuthRespondInvitesBodyInvitesInnerAction](docs/AuthRespondInvitesBodyInvitesInnerAction.md)
 - [AvailabilityFilter](docs/AvailabilityFilter.md)
 - [BaseInviteDataResponse](docs/BaseInviteDataResponse.md)
 - [BaseInviteDataResponseInviteData](docs/BaseInviteDataResponseInviteData.md)
 - [BatchOperation](docs/BatchOperation.md)
 - [BatchOperationStatus](docs/BatchOperationStatus.md)
 - [BidFloor](docs/BidFloor.md)
 - [BidFloorRequest](docs/BidFloorRequest.md)
 - [BidFloorSpec](docs/BidFloorSpec.md)
 - [BillingInvoiceDownloadResponse](docs/BillingInvoiceDownloadResponse.md)
 - [BillingInvoiceResponse](docs/BillingInvoiceResponse.md)
 - [BillingInvoicesGet200Response](docs/BillingInvoicesGet200Response.md)
 - [BillingProfilesGet200Response](docs/BillingProfilesGet200Response.md)
 - [BillingProfilesResponse](docs/BillingProfilesResponse.md)
 - [Board](docs/Board.md)
 - [BoardBase](docs/BoardBase.md)
 - [BoardCreate](docs/BoardCreate.md)
 - [BoardMedia](docs/BoardMedia.md)
 - [BoardOwner](docs/BoardOwner.md)
 - [BoardPrivacy](docs/BoardPrivacy.md)
 - [BoardPrivacyFilter](docs/BoardPrivacyFilter.md)
 - [BoardSection](docs/BoardSection.md)
 - [BoardSectionsList200Response](docs/BoardSectionsList200Response.md)
 - [BoardUpdatePrivacy](docs/BoardUpdatePrivacy.md)
 - [BoardWithUpdatePrivacy](docs/BoardWithUpdatePrivacy.md)
 - [BoardWithUpdatePrivacyUpdate](docs/BoardWithUpdatePrivacyUpdate.md)
 - [BoardsList200Response](docs/BoardsList200Response.md)
 - [BoardsListPins200Response](docs/BoardsListPins200Response.md)
 - [BoardsUserFollowsList200Response](docs/BoardsUserFollowsList200Response.md)
 - [BookClosedResponse](docs/BookClosedResponse.md)
 - [BrandAccountsCreate200Response](docs/BrandAccountsCreate200Response.md)
 - [BrandAccountsCreateRequest](docs/BrandAccountsCreateRequest.md)
 - [BrandAccountsUpdateRequest](docs/BrandAccountsUpdateRequest.md)
 - [BrandFilter](docs/BrandFilter.md)
 - [BudgetType](docs/BudgetType.md)
 - [BulkDownloadRequest](docs/BulkDownloadRequest.md)
 - [BulkDownloadRequestCampaignFilter](docs/BulkDownloadRequestCampaignFilter.md)
 - [BulkDownloadResponse](docs/BulkDownloadResponse.md)
 - [BulkEntityType](docs/BulkEntityType.md)
 - [BulkOutputFormat](docs/BulkOutputFormat.md)
 - [BulkReportingJobStatus](docs/BulkReportingJobStatus.md)
 - [BulkUpsertRequest](docs/BulkUpsertRequest.md)
 - [BulkUpsertRequestCreate](docs/BulkUpsertRequestCreate.md)
 - [BulkUpsertRequestUpdate](docs/BulkUpsertRequestUpdate.md)
 - [BulkUpsertResponse](docs/BulkUpsertResponse.md)
 - [BulkUpsertStatus](docs/BulkUpsertStatus.md)
 - [BulkUpsertStatusResponse](docs/BulkUpsertStatusResponse.md)
 - [BusinessAccessError](docs/BusinessAccessError.md)
 - [BusinessAccessRole](docs/BusinessAccessRole.md)
 - [BusinessAccessUserSummary](docs/BusinessAccessUserSummary.md)
 - [BusinessAssetMembersGet200Response](docs/BusinessAssetMembersGet200Response.md)
 - [BusinessAssetPartnersGet200Response](docs/BusinessAssetPartnersGet200Response.md)
 - [BusinessAssetsGet200Response](docs/BusinessAssetsGet200Response.md)
 - [BusinessMemberAssetsGet200Response](docs/BusinessMemberAssetsGet200Response.md)
 - [BusinessMemberAssetsSummary](docs/BusinessMemberAssetsSummary.md)
 - [BusinessMemberAssetsSummaryAdAccountsInner](docs/BusinessMemberAssetsSummaryAdAccountsInner.md)
 - [BusinessMemberAssetsSummaryProfilesInner](docs/BusinessMemberAssetsSummaryProfilesInner.md)
 - [BusinessMembersAssetAccessDeleteRequest](docs/BusinessMembersAssetAccessDeleteRequest.md)
 - [BusinessMembersAssetAccessDeleteRequestAccessesInner](docs/BusinessMembersAssetAccessDeleteRequestAccessesInner.md)
 - [BusinessPartnerAssetAccessGet200Response](docs/BusinessPartnerAssetAccessGet200Response.md)
 - [BusinessRole](docs/BusinessRole.md)
 - [BusinessRoleCheckMode](docs/BusinessRoleCheckMode.md)
 - [BusinessRoleForMembers](docs/BusinessRoleForMembers.md)
 - [BusinessSharedAudience](docs/BusinessSharedAudience.md)
 - [BusinessSharedAudienceResponse](docs/BusinessSharedAudienceResponse.md)
 - [CampaignAudienceMultipliers](docs/CampaignAudienceMultipliers.md)
 - [CampaignBidOptions](docs/CampaignBidOptions.md)
 - [CampaignBidOptionsCreate](docs/CampaignBidOptionsCreate.md)
 - [CampaignBidOptionsUpdate](docs/CampaignBidOptionsUpdate.md)
 - [CampaignCommon](docs/CampaignCommon.md)
 - [CampaignCreateCommon](docs/CampaignCreateCommon.md)
 - [CampaignCreateRequest](docs/CampaignCreateRequest.md)
 - [CampaignCreateResponse](docs/CampaignCreateResponse.md)
 - [CampaignCreateResponseData](docs/CampaignCreateResponseData.md)
 - [CampaignCreateResponseItem](docs/CampaignCreateResponseItem.md)
 - [CampaignId](docs/CampaignId.md)
 - [CampaignIdFilter](docs/CampaignIdFilter.md)
 - [CampaignObjectivesFilter](docs/CampaignObjectivesFilter.md)
 - [CampaignResponse](docs/CampaignResponse.md)
 - [CampaignSummaryStatus](docs/CampaignSummaryStatus.md)
 - [CampaignUpdateRequest](docs/CampaignUpdateRequest.md)
 - [CampaignUpdateResponse](docs/CampaignUpdateResponse.md)
 - [CampaignsAnalyticsResponseInner](docs/CampaignsAnalyticsResponseInner.md)
 - [CampaignsList200Response](docs/CampaignsList200Response.md)
 - [CancelInvitesBody](docs/CancelInvitesBody.md)
 - [CarouselSlot](docs/CarouselSlot.md)
 - [Catalog](docs/Catalog.md)
 - [CatalogsAvailableFilterValues](docs/CatalogsAvailableFilterValues.md)
 - [CatalogsCreateCreativeAssetsItem](docs/CatalogsCreateCreativeAssetsItem.md)
 - [CatalogsCreateHotelItem](docs/CatalogsCreateHotelItem.md)
 - [CatalogsCreateReportResponse](docs/CatalogsCreateReportResponse.md)
 - [CatalogsCreateRequest](docs/CatalogsCreateRequest.md)
 - [CatalogsCreateRetailItem](docs/CatalogsCreateRetailItem.md)
 - [CatalogsCreativeAssetsAttributes](docs/CatalogsCreativeAssetsAttributes.md)
 - [CatalogsCreativeAssetsAvailableFilterValues](docs/CatalogsCreativeAssetsAvailableFilterValues.md)
 - [CatalogsCreativeAssetsBatchItem](docs/CatalogsCreativeAssetsBatchItem.md)
 - [CatalogsCreativeAssetsBatchRequest](docs/CatalogsCreativeAssetsBatchRequest.md)
 - [CatalogsCreativeAssetsFeed](docs/CatalogsCreativeAssetsFeed.md)
 - [CatalogsCreativeAssetsFeedsCreateRequest](docs/CatalogsCreativeAssetsFeedsCreateRequest.md)
 - [CatalogsCreativeAssetsFeedsUpdateRequest](docs/CatalogsCreativeAssetsFeedsUpdateRequest.md)
 - [CatalogsCreativeAssetsFilterValuesMap](docs/CatalogsCreativeAssetsFilterValuesMap.md)
 - [CatalogsCreativeAssetsItemErrorResponse](docs/CatalogsCreativeAssetsItemErrorResponse.md)
 - [CatalogsCreativeAssetsItemResponse](docs/CatalogsCreativeAssetsItemResponse.md)
 - [CatalogsCreativeAssetsItemsBatch](docs/CatalogsCreativeAssetsItemsBatch.md)
 - [CatalogsCreativeAssetsItemsFilter](docs/CatalogsCreativeAssetsItemsFilter.md)
 - [CatalogsCreativeAssetsItemsPostFilter](docs/CatalogsCreativeAssetsItemsPostFilter.md)
 - [CatalogsCreativeAssetsListProductsByCatalogBasedFilterRequest](docs/CatalogsCreativeAssetsListProductsByCatalogBasedFilterRequest.md)
 - [CatalogsCreativeAssetsProduct](docs/CatalogsCreativeAssetsProduct.md)
 - [CatalogsCreativeAssetsProductGroup](docs/CatalogsCreativeAssetsProductGroup.md)
 - [CatalogsCreativeAssetsProductGroupCreateRequest](docs/CatalogsCreativeAssetsProductGroupCreateRequest.md)
 - [CatalogsCreativeAssetsProductGroupFilterKeys](docs/CatalogsCreativeAssetsProductGroupFilterKeys.md)
 - [CatalogsCreativeAssetsProductGroupFilters](docs/CatalogsCreativeAssetsProductGroupFilters.md)
 - [CatalogsCreativeAssetsProductGroupFiltersAllOf](docs/CatalogsCreativeAssetsProductGroupFiltersAllOf.md)
 - [CatalogsCreativeAssetsProductGroupFiltersAnyOf](docs/CatalogsCreativeAssetsProductGroupFiltersAnyOf.md)
 - [CatalogsCreativeAssetsProductGroupProductCounts](docs/CatalogsCreativeAssetsProductGroupProductCounts.md)
 - [CatalogsCreativeAssetsProductGroupUpdateRequest](docs/CatalogsCreativeAssetsProductGroupUpdateRequest.md)
 - [CatalogsCreativeAssetsProductMetadata](docs/CatalogsCreativeAssetsProductMetadata.md)
 - [CatalogsDbItem](docs/CatalogsDbItem.md)
 - [CatalogsDeleteCreativeAssetsItem](docs/CatalogsDeleteCreativeAssetsItem.md)
 - [CatalogsDeleteHotelItem](docs/CatalogsDeleteHotelItem.md)
 - [CatalogsDeleteRetailItem](docs/CatalogsDeleteRetailItem.md)
 - [CatalogsFeed](docs/CatalogsFeed.md)
 - [CatalogsFeedCredentials](docs/CatalogsFeedCredentials.md)
 - [CatalogsFeedIngestion](docs/CatalogsFeedIngestion.md)
 - [CatalogsFeedIngestionDetails](docs/CatalogsFeedIngestionDetails.md)
 - [CatalogsFeedIngestionErrors](docs/CatalogsFeedIngestionErrors.md)
 - [CatalogsFeedIngestionInfo](docs/CatalogsFeedIngestionInfo.md)
 - [CatalogsFeedIngestionWarnings](docs/CatalogsFeedIngestionWarnings.md)
 - [CatalogsFeedProcessingResult](docs/CatalogsFeedProcessingResult.md)
 - [CatalogsFeedProcessingSchedule](docs/CatalogsFeedProcessingSchedule.md)
 - [CatalogsFeedProcessingStatus](docs/CatalogsFeedProcessingStatus.md)
 - [CatalogsFeedProductCounts](docs/CatalogsFeedProductCounts.md)
 - [CatalogsFeedValidationDetails](docs/CatalogsFeedValidationDetails.md)
 - [CatalogsFeedValidationErrors](docs/CatalogsFeedValidationErrors.md)
 - [CatalogsFeedValidationWarnings](docs/CatalogsFeedValidationWarnings.md)
 - [CatalogsFeedVideoCounts](docs/CatalogsFeedVideoCounts.md)
 - [CatalogsFeedsCreateRequest](docs/CatalogsFeedsCreateRequest.md)
 - [CatalogsFeedsCreateRequestDefaultLocale](docs/CatalogsFeedsCreateRequestDefaultLocale.md)
 - [CatalogsFeedsUpdateRequest](docs/CatalogsFeedsUpdateRequest.md)
 - [CatalogsFormat](docs/CatalogsFormat.md)
 - [CatalogsHotelAddress](docs/CatalogsHotelAddress.md)
 - [CatalogsHotelAttributes](docs/CatalogsHotelAttributes.md)
 - [CatalogsHotelAttributesAllOfMainImage](docs/CatalogsHotelAttributesAllOfMainImage.md)
 - [CatalogsHotelAvailableFilterValues](docs/CatalogsHotelAvailableFilterValues.md)
 - [CatalogsHotelBatchItem](docs/CatalogsHotelBatchItem.md)
 - [CatalogsHotelBatchRequest](docs/CatalogsHotelBatchRequest.md)
 - [CatalogsHotelFeed](docs/CatalogsHotelFeed.md)
 - [CatalogsHotelFeedsCreateRequest](docs/CatalogsHotelFeedsCreateRequest.md)
 - [CatalogsHotelFeedsUpdateRequest](docs/CatalogsHotelFeedsUpdateRequest.md)
 - [CatalogsHotelFilterValuesMap](docs/CatalogsHotelFilterValuesMap.md)
 - [CatalogsHotelGuestRatings](docs/CatalogsHotelGuestRatings.md)
 - [CatalogsHotelItemErrorResponse](docs/CatalogsHotelItemErrorResponse.md)
 - [CatalogsHotelItemResponse](docs/CatalogsHotelItemResponse.md)
 - [CatalogsHotelItemsBatch](docs/CatalogsHotelItemsBatch.md)
 - [CatalogsHotelItemsFilter](docs/CatalogsHotelItemsFilter.md)
 - [CatalogsHotelItemsPostFilter](docs/CatalogsHotelItemsPostFilter.md)
 - [CatalogsHotelListProductsByCatalogBasedFilterRequest](docs/CatalogsHotelListProductsByCatalogBasedFilterRequest.md)
 - [CatalogsHotelProduct](docs/CatalogsHotelProduct.md)
 - [CatalogsHotelProductGroup](docs/CatalogsHotelProductGroup.md)
 - [CatalogsHotelProductGroupCreateRequest](docs/CatalogsHotelProductGroupCreateRequest.md)
 - [CatalogsHotelProductGroupFilterKeys](docs/CatalogsHotelProductGroupFilterKeys.md)
 - [CatalogsHotelProductGroupFilters](docs/CatalogsHotelProductGroupFilters.md)
 - [CatalogsHotelProductGroupFiltersAllOf](docs/CatalogsHotelProductGroupFiltersAllOf.md)
 - [CatalogsHotelProductGroupFiltersAnyOf](docs/CatalogsHotelProductGroupFiltersAnyOf.md)
 - [CatalogsHotelProductGroupProductCounts](docs/CatalogsHotelProductGroupProductCounts.md)
 - [CatalogsHotelProductGroupType](docs/CatalogsHotelProductGroupType.md)
 - [CatalogsHotelProductGroupUpdateRequest](docs/CatalogsHotelProductGroupUpdateRequest.md)
 - [CatalogsHotelProductMetadata](docs/CatalogsHotelProductMetadata.md)
 - [CatalogsHotelReportParameters](docs/CatalogsHotelReportParameters.md)
 - [CatalogsHotelReportParametersReport](docs/CatalogsHotelReportParametersReport.md)
 - [CatalogsHotelReportStatsParameters](docs/CatalogsHotelReportStatsParameters.md)
 - [CatalogsHotelReportStatsParametersReport](docs/CatalogsHotelReportStatsParametersReport.md)
 - [CatalogsItemValidationDetails](docs/CatalogsItemValidationDetails.md)
 - [CatalogsItemValidationErrors](docs/CatalogsItemValidationErrors.md)
 - [CatalogsItemValidationIssue](docs/CatalogsItemValidationIssue.md)
 - [CatalogsItemValidationIssues](docs/CatalogsItemValidationIssues.md)
 - [CatalogsItemValidationWarnings](docs/CatalogsItemValidationWarnings.md)
 - [CatalogsItems](docs/CatalogsItems.md)
 - [CatalogsItemsBatch](docs/CatalogsItemsBatch.md)
 - [CatalogsItemsBatchRequest](docs/CatalogsItemsBatchRequest.md)
 - [CatalogsItemsCreateBatchRequest](docs/CatalogsItemsCreateBatchRequest.md)
 - [CatalogsItemsDeleteBatchRequest](docs/CatalogsItemsDeleteBatchRequest.md)
 - [CatalogsItemsDeleteDiscontinuedBatchRequest](docs/CatalogsItemsDeleteDiscontinuedBatchRequest.md)
 - [CatalogsItemsFilters](docs/CatalogsItemsFilters.md)
 - [CatalogsItemsPostFilters](docs/CatalogsItemsPostFilters.md)
 - [CatalogsItemsRequest](docs/CatalogsItemsRequest.md)
 - [CatalogsItemsUpdateBatchRequest](docs/CatalogsItemsUpdateBatchRequest.md)
 - [CatalogsItemsUpsertBatchRequest](docs/CatalogsItemsUpsertBatchRequest.md)
 - [CatalogsList200Response](docs/CatalogsList200Response.md)
 - [CatalogsListProductsByFeedBasedFilter](docs/CatalogsListProductsByFeedBasedFilter.md)
 - [CatalogsListProductsByFilterRequest](docs/CatalogsListProductsByFilterRequest.md)
 - [CatalogsLocale](docs/CatalogsLocale.md)
 - [CatalogsProduct](docs/CatalogsProduct.md)
 - [CatalogsProductGroupCreateRequest](docs/CatalogsProductGroupCreateRequest.md)
 - [CatalogsProductGroupCurrencyCriteria](docs/CatalogsProductGroupCurrencyCriteria.md)
 - [CatalogsProductGroupFilterKeys](docs/CatalogsProductGroupFilterKeys.md)
 - [CatalogsProductGroupFilterOperatorTypeCriteria](docs/CatalogsProductGroupFilterOperatorTypeCriteria.md)
 - [CatalogsProductGroupFilters](docs/CatalogsProductGroupFilters.md)
 - [CatalogsProductGroupFiltersAllOf](docs/CatalogsProductGroupFiltersAllOf.md)
 - [CatalogsProductGroupFiltersAnyOf](docs/CatalogsProductGroupFiltersAnyOf.md)
 - [CatalogsProductGroupFiltersRequest](docs/CatalogsProductGroupFiltersRequest.md)
 - [CatalogsProductGroupMultipleCountriesCriteria](docs/CatalogsProductGroupMultipleCountriesCriteria.md)
 - [CatalogsProductGroupMultipleGenderCriteria](docs/CatalogsProductGroupMultipleGenderCriteria.md)
 - [CatalogsProductGroupMultipleMediaTypesCriteria](docs/CatalogsProductGroupMultipleMediaTypesCriteria.md)
 - [CatalogsProductGroupMultipleStringCriteria](docs/CatalogsProductGroupMultipleStringCriteria.md)
 - [CatalogsProductGroupMultipleStringListCriteria](docs/CatalogsProductGroupMultipleStringListCriteria.md)
 - [CatalogsProductGroupPinsList200Response](docs/CatalogsProductGroupPinsList200Response.md)
 - [CatalogsProductGroupPricingCriteria](docs/CatalogsProductGroupPricingCriteria.md)
 - [CatalogsProductGroupPricingCurrencyCriteria](docs/CatalogsProductGroupPricingCurrencyCriteria.md)
 - [CatalogsProductGroupProductCountsVertical](docs/CatalogsProductGroupProductCountsVertical.md)
 - [CatalogsProductGroupStatus](docs/CatalogsProductGroupStatus.md)
 - [CatalogsProductGroupType](docs/CatalogsProductGroupType.md)
 - [CatalogsProductGroupUint32Criteria](docs/CatalogsProductGroupUint32Criteria.md)
 - [CatalogsProductGroupUpdateRequest](docs/CatalogsProductGroupUpdateRequest.md)
 - [CatalogsProductGroupsList200Response](docs/CatalogsProductGroupsList200Response.md)
 - [CatalogsProductGroupsUpdateRequest](docs/CatalogsProductGroupsUpdateRequest.md)
 - [CatalogsReport](docs/CatalogsReport.md)
 - [CatalogsReportAllItemsFilter](docs/CatalogsReportAllItemsFilter.md)
 - [CatalogsReportDistributionIssueFilter](docs/CatalogsReportDistributionIssueFilter.md)
 - [CatalogsReportDistributionStats](docs/CatalogsReportDistributionStats.md)
 - [CatalogsReportFeedIngestionFilter](docs/CatalogsReportFeedIngestionFilter.md)
 - [CatalogsReportFeedIngestionStats](docs/CatalogsReportFeedIngestionStats.md)
 - [CatalogsReportParameters](docs/CatalogsReportParameters.md)
 - [CatalogsReportStats](docs/CatalogsReportStats.md)
 - [CatalogsRetailAvailableFilterValues](docs/CatalogsRetailAvailableFilterValues.md)
 - [CatalogsRetailBatchRequest](docs/CatalogsRetailBatchRequest.md)
 - [CatalogsRetailBatchRequestItemsInner](docs/CatalogsRetailBatchRequestItemsInner.md)
 - [CatalogsRetailFeed](docs/CatalogsRetailFeed.md)
 - [CatalogsRetailFeedsCreateRequest](docs/CatalogsRetailFeedsCreateRequest.md)
 - [CatalogsRetailFeedsUpdateRequest](docs/CatalogsRetailFeedsUpdateRequest.md)
 - [CatalogsRetailFilterValuesMap](docs/CatalogsRetailFilterValuesMap.md)
 - [CatalogsRetailItemErrorResponse](docs/CatalogsRetailItemErrorResponse.md)
 - [CatalogsRetailItemResponse](docs/CatalogsRetailItemResponse.md)
 - [CatalogsRetailItemsBatch](docs/CatalogsRetailItemsBatch.md)
 - [CatalogsRetailItemsFilter](docs/CatalogsRetailItemsFilter.md)
 - [CatalogsRetailItemsPostFilter](docs/CatalogsRetailItemsPostFilter.md)
 - [CatalogsRetailListProductsByCatalogBasedFilterRequest](docs/CatalogsRetailListProductsByCatalogBasedFilterRequest.md)
 - [CatalogsRetailProduct](docs/CatalogsRetailProduct.md)
 - [CatalogsRetailProductGroup](docs/CatalogsRetailProductGroup.md)
 - [CatalogsRetailProductGroupCreateRequest](docs/CatalogsRetailProductGroupCreateRequest.md)
 - [CatalogsRetailProductGroupProductCounts](docs/CatalogsRetailProductGroupProductCounts.md)
 - [CatalogsRetailProductGroupUpdateRequest](docs/CatalogsRetailProductGroupUpdateRequest.md)
 - [CatalogsRetailProductMetadata](docs/CatalogsRetailProductMetadata.md)
 - [CatalogsRetailReportParameters](docs/CatalogsRetailReportParameters.md)
 - [CatalogsRetailReportStatsParameters](docs/CatalogsRetailReportStatsParameters.md)
 - [CatalogsStatus](docs/CatalogsStatus.md)
 - [CatalogsType](docs/CatalogsType.md)
 - [CatalogsUpdatableCreativeAssetsAttributes](docs/CatalogsUpdatableCreativeAssetsAttributes.md)
 - [CatalogsUpdatableHotelAttributes](docs/CatalogsUpdatableHotelAttributes.md)
 - [CatalogsUpdateCreativeAssetsItem](docs/CatalogsUpdateCreativeAssetsItem.md)
 - [CatalogsUpdateHotelItem](docs/CatalogsUpdateHotelItem.md)
 - [CatalogsUpdateRetailItem](docs/CatalogsUpdateRetailItem.md)
 - [CatalogsUpsertCreativeAssetsItem](docs/CatalogsUpsertCreativeAssetsItem.md)
 - [CatalogsUpsertHotelItem](docs/CatalogsUpsertHotelItem.md)
 - [CatalogsUpsertRetailItem](docs/CatalogsUpsertRetailItem.md)
 - [CatalogsVerticalBatchRequest](docs/CatalogsVerticalBatchRequest.md)
 - [CatalogsVerticalFeedsCreateRequest](docs/CatalogsVerticalFeedsCreateRequest.md)
 - [CatalogsVerticalFeedsUpdateRequest](docs/CatalogsVerticalFeedsUpdateRequest.md)
 - [CatalogsVerticalProductGroup](docs/CatalogsVerticalProductGroup.md)
 - [CatalogsVerticalProductGroupCreateRequest](docs/CatalogsVerticalProductGroupCreateRequest.md)
 - [CatalogsVerticalProductGroupUpdateRequest](docs/CatalogsVerticalProductGroupUpdateRequest.md)
 - [CatalogsVerticalsListProductsByCatalogBasedFilterRequest](docs/CatalogsVerticalsListProductsByCatalogBasedFilterRequest.md)
 - [ConditionFilter](docs/ConditionFilter.md)
 - [ContentType](docs/ContentType.md)
 - [ConversionAccessTokenResponse](docs/ConversionAccessTokenResponse.md)
 - [ConversionApiResponse](docs/ConversionApiResponse.md)
 - [ConversionApiResponseEventsInner](docs/ConversionApiResponseEventsInner.md)
 - [ConversionAttributionWindowDays](docs/ConversionAttributionWindowDays.md)
 - [ConversionEventAppInfo](docs/ConversionEventAppInfo.md)
 - [ConversionEventDeviceInfo](docs/ConversionEventDeviceInfo.md)
 - [ConversionEventResponse](docs/ConversionEventResponse.md)
 - [ConversionEvents](docs/ConversionEvents.md)
 - [ConversionEventsDataInner](docs/ConversionEventsDataInner.md)
 - [ConversionEventsDataInnerCustomData](docs/ConversionEventsDataInnerCustomData.md)
 - [ConversionEventsDataInnerCustomDataContentsInner](docs/ConversionEventsDataInnerCustomDataContentsInner.md)
 - [ConversionEventsUserData](docs/ConversionEventsUserData.md)
 - [ConversionEventsUserDataProperties](docs/ConversionEventsUserDataProperties.md)
 - [ConversionHealthSelectionItem](docs/ConversionHealthSelectionItem.md)
 - [ConversionMSOTEvents](docs/ConversionMSOTEvents.md)
 - [ConversionProductReportRequest](docs/ConversionProductReportRequest.md)
 - [ConversionProductReportingColumn](docs/ConversionProductReportingColumn.md)
 - [ConversionReportAttributionType](docs/ConversionReportAttributionType.md)
 - [ConversionReportTimeType](docs/ConversionReportTimeType.md)
 - [ConversionTag](docs/ConversionTag.md)
 - [ConversionTagCommon](docs/ConversionTagCommon.md)
 - [ConversionTagConfigs](docs/ConversionTagConfigs.md)
 - [ConversionTagCreate](docs/ConversionTagCreate.md)
 - [ConversionTagListResponse](docs/ConversionTagListResponse.md)
 - [ConversionTagResponse](docs/ConversionTagResponse.md)
 - [ConversionTagType](docs/ConversionTagType.md)
 - [ConversionTagsList200Response](docs/ConversionTagsList200Response.md)
 - [Country](docs/Country.md)
 - [CountryFilter](docs/CountryFilter.md)
 - [CreateAssetAccessRequestBody](docs/CreateAssetAccessRequestBody.md)
 - [CreateAssetAccessRequestBodyAssetRequestsInner](docs/CreateAssetAccessRequestBodyAssetRequestsInner.md)
 - [CreateAssetAccessRequestErrorMessageInner](docs/CreateAssetAccessRequestErrorMessageInner.md)
 - [CreateAssetAccessRequestResponse](docs/CreateAssetAccessRequestResponse.md)
 - [CreateAssetGroupBody](docs/CreateAssetGroupBody.md)
 - [CreateAssetGroupResponse](docs/CreateAssetGroupResponse.md)
 - [CreateAssetInvitesRequest](docs/CreateAssetInvitesRequest.md)
 - [CreateAssetInvitesRequestItem](docs/CreateAssetInvitesRequestItem.md)
 - [CreateInvitesResultsResponseArray](docs/CreateInvitesResultsResponseArray.md)
 - [CreateInvitesResultsResponseArrayItemsInner](docs/CreateInvitesResultsResponseArrayItemsInner.md)
 - [CreateInvitesResultsResponseArrayItemsInnerInvite](docs/CreateInvitesResultsResponseArrayItemsInnerInvite.md)
 - [CreateMMMReportRequest](docs/CreateMMMReportRequest.md)
 - [CreateMMMReportResponse](docs/CreateMMMReportResponse.md)
 - [CreateMMMReportResponseData](docs/CreateMMMReportResponseData.md)
 - [CreateMembershipOrPartnershipInvitesBody](docs/CreateMembershipOrPartnershipInvitesBody.md)
 - [CreativeAssetsIdFilter](docs/CreativeAssetsIdFilter.md)
 - [CreativeAssetsProcessingRecord](docs/CreativeAssetsProcessingRecord.md)
 - [CreativeAssetsVisibilityType](docs/CreativeAssetsVisibilityType.md)
 - [CreativeType](docs/CreativeType.md)
 - [Currency](docs/Currency.md)
 - [CurrencyFilter](docs/CurrencyFilter.md)
 - [CustomLabel0Filter](docs/CustomLabel0Filter.md)
 - [CustomLabel1Filter](docs/CustomLabel1Filter.md)
 - [CustomLabel2Filter](docs/CustomLabel2Filter.md)
 - [CustomLabel3Filter](docs/CustomLabel3Filter.md)
 - [CustomLabel4Filter](docs/CustomLabel4Filter.md)
 - [CustomNumber0Filter](docs/CustomNumber0Filter.md)
 - [CustomNumber1Filter](docs/CustomNumber1Filter.md)
 - [CustomNumber2Filter](docs/CustomNumber2Filter.md)
 - [CustomNumber3Filter](docs/CustomNumber3Filter.md)
 - [CustomNumber4Filter](docs/CustomNumber4Filter.md)
 - [CustomerList](docs/CustomerList.md)
 - [CustomerListRequest](docs/CustomerListRequest.md)
 - [CustomerListUpdateRequest](docs/CustomerListUpdateRequest.md)
 - [CustomerListUpload](docs/CustomerListUpload.md)
 - [CustomerListUploadCreateRequest](docs/CustomerListUploadCreateRequest.md)
 - [CustomerListUploadCreateResponse](docs/CustomerListUploadCreateResponse.md)
 - [CustomerListUploadResponse](docs/CustomerListUploadResponse.md)
 - [CustomerListsList200Response](docs/CustomerListsList200Response.md)
 - [CustomizableCTAType](docs/CustomizableCTAType.md)
 - [DataOutputFormat](docs/DataOutputFormat.md)
 - [DataStatus](docs/DataStatus.md)
 - [DeleteAssetGroupBody](docs/DeleteAssetGroupBody.md)
 - [DeleteAssetGroupResponse](docs/DeleteAssetGroupResponse.md)
 - [DeleteAssetGroupResponseExceptionsInner](docs/DeleteAssetGroupResponseExceptionsInner.md)
 - [DeleteInvitesResultsResponseArray](docs/DeleteInvitesResultsResponseArray.md)
 - [DeleteInvitesResultsResponseArrayItemsInner](docs/DeleteInvitesResultsResponseArrayItemsInner.md)
 - [DeleteInvitesResultsResponseArrayItemsInnerException](docs/DeleteInvitesResultsResponseArrayItemsInnerException.md)
 - [DeleteMemberAccessResult](docs/DeleteMemberAccessResult.md)
 - [DeleteMemberAccessResultsResponseArray](docs/DeleteMemberAccessResultsResponseArray.md)
 - [DeletePartnerAssetAccessBody](docs/DeletePartnerAssetAccessBody.md)
 - [DeletePartnerAssetAccessBodyAccessesInner](docs/DeletePartnerAssetAccessBodyAccessesInner.md)
 - [DeletePartnerAssetsResult](docs/DeletePartnerAssetsResult.md)
 - [DeletePartnerAssetsResultsResponseArray](docs/DeletePartnerAssetsResultsResponseArray.md)
 - [DeletePartnersRequest](docs/DeletePartnersRequest.md)
 - [DeletePartnersResponse](docs/DeletePartnersResponse.md)
 - [DeletedMembersResponse](docs/DeletedMembersResponse.md)
 - [DeliveryMetricsResponse](docs/DeliveryMetricsResponse.md)
 - [DeliveryMetricsResponseItemsInner](docs/DeliveryMetricsResponseItemsInner.md)
 - [DetailedError](docs/DetailedError.md)
 - [DisclosureType](docs/DisclosureType.md)
 - [EnhancedMatchStatusType](docs/EnhancedMatchStatusType.md)
 - [EntityStatus](docs/EntityStatus.md)
 - [Error](docs/Error.md)
 - [ErrorDetail](docs/ErrorDetail.md)
 - [EventData](docs/EventData.md)
 - [EventQualityScore](docs/EventQualityScore.md)
 - [Exception](docs/Exception.md)
 - [FeaturedTrend](docs/FeaturedTrend.md)
 - [FeedProcessingResultsList200Response](docs/FeedProcessingResultsList200Response.md)
 - [FeedsCreateRequest](docs/FeedsCreateRequest.md)
 - [FeedsList200Response](docs/FeedsList200Response.md)
 - [FeedsUpdateRequest](docs/FeedsUpdateRequest.md)
 - [FollowUserRequest](docs/FollowUserRequest.md)
 - [FollowersList200Response](docs/FollowersList200Response.md)
 - [Gender](docs/Gender.md)
 - [GenderBucket](docs/GenderBucket.md)
 - [GenderDemographics](docs/GenderDemographics.md)
 - [GenderFilter](docs/GenderFilter.md)
 - [GetAudiencesOrderBy](docs/GetAudiencesOrderBy.md)
 - [GetBusinessAssetTypeResponse](docs/GetBusinessAssetTypeResponse.md)
 - [GetBusinessAssetsResponse](docs/GetBusinessAssetsResponse.md)
 - [GetBusinessAssetsResponseCatalogInfo](docs/GetBusinessAssetsResponseCatalogInfo.md)
 - [GetBusinessEmployers200Response](docs/GetBusinessEmployers200Response.md)
 - [GetBusinessMembers200Response](docs/GetBusinessMembers200Response.md)
 - [GetBusinessPartners200Response](docs/GetBusinessPartners200Response.md)
 - [GetInvites200Response](docs/GetInvites200Response.md)
 - [GetMMMReportResponse](docs/GetMMMReportResponse.md)
 - [GetMMMReportResponseData](docs/GetMMMReportResponseData.md)
 - [GetPartnerAssetsResponse](docs/GetPartnerAssetsResponse.md)
 - [GoogleProductCategory0Filter](docs/GoogleProductCategory0Filter.md)
 - [GoogleProductCategory1Filter](docs/GoogleProductCategory1Filter.md)
 - [GoogleProductCategory2Filter](docs/GoogleProductCategory2Filter.md)
 - [GoogleProductCategory3Filter](docs/GoogleProductCategory3Filter.md)
 - [GoogleProductCategory4Filter](docs/GoogleProductCategory4Filter.md)
 - [GoogleProductCategory5Filter](docs/GoogleProductCategory5Filter.md)
 - [GoogleProductCategory6Filter](docs/GoogleProductCategory6Filter.md)
 - [Granularity](docs/Granularity.md)
 - [GridClickType](docs/GridClickType.md)
 - [HotelIdFilter](docs/HotelIdFilter.md)
 - [HotelProcessingRecord](docs/HotelProcessingRecord.md)
 - [ImageBase64](docs/ImageBase64.md)
 - [ImageDetails](docs/ImageDetails.md)
 - [ImageMetadata](docs/ImageMetadata.md)
 - [ImageSize](docs/ImageSize.md)
 - [IngestionSourceOptions](docs/IngestionSourceOptions.md)
 - [InnerProductCategoriesMetricsHighlights](docs/InnerProductCategoriesMetricsHighlights.md)
 - [IntegrationLog](docs/IntegrationLog.md)
 - [IntegrationLogClientError](docs/IntegrationLogClientError.md)
 - [IntegrationLogClientRequest](docs/IntegrationLogClientRequest.md)
 - [IntegrationLogsInvalidLogResponse](docs/IntegrationLogsInvalidLogResponse.md)
 - [IntegrationLogsInvalidLogResponseRejectedLogsInner](docs/IntegrationLogsInvalidLogResponseRejectedLogsInner.md)
 - [IntegrationLogsRequest](docs/IntegrationLogsRequest.md)
 - [IntegrationLogsSuccessResponse](docs/IntegrationLogsSuccessResponse.md)
 - [IntegrationMetadata](docs/IntegrationMetadata.md)
 - [IntegrationRecord](docs/IntegrationRecord.md)
 - [IntegrationRequest](docs/IntegrationRequest.md)
 - [IntegrationRequestPatch](docs/IntegrationRequestPatch.md)
 - [IntegrationsGetList200Response](docs/IntegrationsGetList200Response.md)
 - [IntegrationsLogsPost400Response](docs/IntegrationsLogsPost400Response.md)
 - [Interest](docs/Interest.md)
 - [InterestsEnum](docs/InterestsEnum.md)
 - [InviteAssetsSummary](docs/InviteAssetsSummary.md)
 - [InviteAssetsSummaryAdAccountsInner](docs/InviteAssetsSummaryAdAccountsInner.md)
 - [InviteAssetsSummaryProfilesInner](docs/InviteAssetsSummaryProfilesInner.md)
 - [InviteBusinessRoleBinding](docs/InviteBusinessRoleBinding.md)
 - [InviteExceptionResponse](docs/InviteExceptionResponse.md)
 - [InviteResponse](docs/InviteResponse.md)
 - [InviteStatus](docs/InviteStatus.md)
 - [InviteType](docs/InviteType.md)
 - [ItemAttributes](docs/ItemAttributes.md)
 - [ItemAttributesRequest](docs/ItemAttributesRequest.md)
 - [ItemAttributesRequestAllOfImageLink](docs/ItemAttributesRequestAllOfImageLink.md)
 - [ItemBatchRecord](docs/ItemBatchRecord.md)
 - [ItemCreateBatchRecord](docs/ItemCreateBatchRecord.md)
 - [ItemDeleteBatchRecord](docs/ItemDeleteBatchRecord.md)
 - [ItemDeleteDiscontinuedBatchRecord](docs/ItemDeleteDiscontinuedBatchRecord.md)
 - [ItemGroupIdFilter](docs/ItemGroupIdFilter.md)
 - [ItemIdFilter](docs/ItemIdFilter.md)
 - [ItemProcessingRecord](docs/ItemProcessingRecord.md)
 - [ItemProcessingStatus](docs/ItemProcessingStatus.md)
 - [ItemResponse](docs/ItemResponse.md)
 - [ItemResponseOneOf](docs/ItemResponseOneOf.md)
 - [ItemResponseOneOf1](docs/ItemResponseOneOf1.md)
 - [ItemUpdateBatchRecord](docs/ItemUpdateBatchRecord.md)
 - [ItemUpsertBatchRecord](docs/ItemUpsertBatchRecord.md)
 - [ItemValidationEvent](docs/ItemValidationEvent.md)
 - [ItemsBatchPostRequest](docs/ItemsBatchPostRequest.md)
 - [ItemsIssuesList200Response](docs/ItemsIssuesList200Response.md)
 - [Keyword](docs/Keyword.md)
 - [KeywordError](docs/KeywordError.md)
 - [KeywordMetrics](docs/KeywordMetrics.md)
 - [KeywordMetricsResponse](docs/KeywordMetricsResponse.md)
 - [KeywordUpdate](docs/KeywordUpdate.md)
 - [KeywordUpdateBody](docs/KeywordUpdateBody.md)
 - [KeywordsCommon](docs/KeywordsCommon.md)
 - [KeywordsGet200Response](docs/KeywordsGet200Response.md)
 - [KeywordsMetricsArrayResponse](docs/KeywordsMetricsArrayResponse.md)
 - [KeywordsRequest](docs/KeywordsRequest.md)
 - [KeywordsResponse](docs/KeywordsResponse.md)
 - [Label](docs/Label.md)
 - [LabelBulkUpdateRequest](docs/LabelBulkUpdateRequest.md)
 - [LabelCreateRequest](docs/LabelCreateRequest.md)
 - [LabelCreateRequestLabelsInner](docs/LabelCreateRequestLabelsInner.md)
 - [LabelError](docs/LabelError.md)
 - [LabelParentType](docs/LabelParentType.md)
 - [LabelStatus](docs/LabelStatus.md)
 - [LabelType](docs/LabelType.md)
 - [LabelUpdateRequest](docs/LabelUpdateRequest.md)
 - [LabelUpdateRequestLabelsInner](docs/LabelUpdateRequestLabelsInner.md)
 - [LabelsList200Response](docs/LabelsList200Response.md)
 - [LabelsResponse](docs/LabelsResponse.md)
 - [Language](docs/Language.md)
 - [LeadFormArrayResponse](docs/LeadFormArrayResponse.md)
 - [LeadFormArrayResponseItemsInner](docs/LeadFormArrayResponseItemsInner.md)
 - [LeadFormCommon](docs/LeadFormCommon.md)
 - [LeadFormCommonPolicyLinksInner](docs/LeadFormCommonPolicyLinksInner.md)
 - [LeadFormCreateRequest](docs/LeadFormCreateRequest.md)
 - [LeadFormQuestion](docs/LeadFormQuestion.md)
 - [LeadFormQuestionFieldType](docs/LeadFormQuestionFieldType.md)
 - [LeadFormQuestionType](docs/LeadFormQuestionType.md)
 - [LeadFormResponse](docs/LeadFormResponse.md)
 - [LeadFormStatus](docs/LeadFormStatus.md)
 - [LeadFormTestRequest](docs/LeadFormTestRequest.md)
 - [LeadFormTestResponse](docs/LeadFormTestResponse.md)
 - [LeadFormUpdateRequest](docs/LeadFormUpdateRequest.md)
 - [LeadFormsList200Response](docs/LeadFormsList200Response.md)
 - [LeadSubscription](docs/LeadSubscription.md)
 - [LeadSubscriptionPostParamsCreate](docs/LeadSubscriptionPostParamsCreate.md)
 - [LeadSubscriptionPostParamsCreateAllOfPartnerMetadata](docs/LeadSubscriptionPostParamsCreateAllOfPartnerMetadata.md)
 - [LeadsExportCreateRequest](docs/LeadsExportCreateRequest.md)
 - [LeadsExportCreateResponse](docs/LeadsExportCreateResponse.md)
 - [LeadsExportResponseData](docs/LeadsExportResponseData.md)
 - [LeadsExportStatus](docs/LeadsExportStatus.md)
 - [LineItem](docs/LineItem.md)
 - [LinkedBusiness](docs/LinkedBusiness.md)
 - [LocalStoreUpdate](docs/LocalStoreUpdate.md)
 - [LookbackPeriodOptions](docs/LookbackPeriodOptions.md)
 - [MMMReportingColumn](docs/MMMReportingColumn.md)
 - [MMMReportingTargetingType](docs/MMMReportingTargetingType.md)
 - [MatchType](docs/MatchType.md)
 - [MatchTypeResponse](docs/MatchTypeResponse.md)
 - [MaxPriceFilter](docs/MaxPriceFilter.md)
 - [Media](docs/Media.md)
 - [MediaList200Response](docs/MediaList200Response.md)
 - [MediaType](docs/MediaType.md)
 - [MediaTypeFilter](docs/MediaTypeFilter.md)
 - [MediaUpload](docs/MediaUpload.md)
 - [MediaUploadCreate](docs/MediaUploadCreate.md)
 - [MediaUploadParameters](docs/MediaUploadParameters.md)
 - [MediaUploadStatus](docs/MediaUploadStatus.md)
 - [MediaUploadType](docs/MediaUploadType.md)
 - [MemberBusinessRole](docs/MemberBusinessRole.md)
 - [MembersToDeleteBody](docs/MembersToDeleteBody.md)
 - [MembersToDeleteBodyMembersInner](docs/MembersToDeleteBodyMembersInner.md)
 - [MetricsReportingLevel](docs/MetricsReportingLevel.md)
 - [MetricsResponse](docs/MetricsResponse.md)
 - [MinPriceFilter](docs/MinPriceFilter.md)
 - [MultipleProductGroupsInner](docs/MultipleProductGroupsInner.md)
 - [NonDraftEntityStatus](docs/NonDraftEntityStatus.md)
 - [NonNullableCatalogsCurrency](docs/NonNullableCatalogsCurrency.md)
 - [NonNullableProductAvailabilityType](docs/NonNullableProductAvailabilityType.md)
 - [NotificationPostRequest](docs/NotificationPostRequest.md)
 - [NotificationResponse](docs/NotificationResponse.md)
 - [NullableCatalogsItemFieldType](docs/NullableCatalogsItemFieldType.md)
 - [NullableCurrency](docs/NullableCurrency.md)
 - [OauthAccessTokenRequestClientCredentials](docs/OauthAccessTokenRequestClientCredentials.md)
 - [OauthAccessTokenRequestCode](docs/OauthAccessTokenRequestCode.md)
 - [OauthAccessTokenRequestRefresh](docs/OauthAccessTokenRequestRefresh.md)
 - [OauthAccessTokenResponse](docs/OauthAccessTokenResponse.md)
 - [OauthAccessTokenResponseClientCredentials](docs/OauthAccessTokenResponseClientCredentials.md)
 - [OauthAccessTokenResponseCode](docs/OauthAccessTokenResponseCode.md)
 - [OauthAccessTokenResponseIntegrationRefresh](docs/OauthAccessTokenResponseIntegrationRefresh.md)
 - [OauthAccessTokenResponseRefresh](docs/OauthAccessTokenResponseRefresh.md)
 - [ObjectiveType](docs/ObjectiveType.md)
 - [OperationType](docs/OperationType.md)
 - [OptimizationGoalMetadata](docs/OptimizationGoalMetadata.md)
 - [OptimizationGoalMetadataConversionTagV3GoalMetadata](docs/OptimizationGoalMetadataConversionTagV3GoalMetadata.md)
 - [OptimizationGoalMetadataConversionTagV3GoalMetadataAttributionWindows](docs/OptimizationGoalMetadataConversionTagV3GoalMetadataAttributionWindows.md)
 - [OptimizationGoalMetadataFrequencyGoalMetadata](docs/OptimizationGoalMetadataFrequencyGoalMetadata.md)
 - [OptimizationGoalMetadataScrollupGoalMetadata](docs/OptimizationGoalMetadataScrollupGoalMetadata.md)
 - [OrderLine](docs/OrderLine.md)
 - [OrderLineError](docs/OrderLineError.md)
 - [OrderLinePaidType](docs/OrderLinePaidType.md)
 - [OrderLineResponse](docs/OrderLineResponse.md)
 - [OrderLineSingleResponse](docs/OrderLineSingleResponse.md)
 - [OrderLineStatus](docs/OrderLineStatus.md)
 - [OrderLines](docs/OrderLines.md)
 - [OrderLinesArrayResponse](docs/OrderLinesArrayResponse.md)
 - [OrderLinesList200Response](docs/OrderLinesList200Response.md)
 - [OverallStatusOptions](docs/OverallStatusOptions.md)
 - [PacingDeliveryType](docs/PacingDeliveryType.md)
 - [PageVisitConversionTagsGet200Response](docs/PageVisitConversionTagsGet200Response.md)
 - [Paginated](docs/Paginated.md)
 - [PartnerType](docs/PartnerType.md)
 - [Permissions](docs/Permissions.md)
 - [PermissionsWithOwner](docs/PermissionsWithOwner.md)
 - [Pin](docs/Pin.md)
 - [PinAnalyticsMetricsResponse](docs/PinAnalyticsMetricsResponse.md)
 - [PinAnalyticsMetricsResponseDailyMetricsInner](docs/PinAnalyticsMetricsResponseDailyMetricsInner.md)
 - [PinCreate](docs/PinCreate.md)
 - [PinMedia](docs/PinMedia.md)
 - [PinMediaMetadata](docs/PinMediaMetadata.md)
 - [PinMediaSource](docs/PinMediaSource.md)
 - [PinMediaSourceImageBase64](docs/PinMediaSourceImageBase64.md)
 - [PinMediaSourceImageURL](docs/PinMediaSourceImageURL.md)
 - [PinMediaSourceImagesBase64](docs/PinMediaSourceImagesBase64.md)
 - [PinMediaSourceImagesBase64Item](docs/PinMediaSourceImagesBase64Item.md)
 - [PinMediaSourceImagesURL](docs/PinMediaSourceImagesURL.md)
 - [PinMediaSourceImagesURLItem](docs/PinMediaSourceImagesURLItem.md)
 - [PinMediaSourcePinURL](docs/PinMediaSourcePinURL.md)
 - [PinMediaSourceVideoID](docs/PinMediaSourceVideoID.md)
 - [PinMediaWithImage](docs/PinMediaWithImage.md)
 - [PinMediaWithImageAndVideo](docs/PinMediaWithImageAndVideo.md)
 - [PinMediaWithImages](docs/PinMediaWithImages.md)
 - [PinMediaWithVideo](docs/PinMediaWithVideo.md)
 - [PinMediaWithVideos](docs/PinMediaWithVideos.md)
 - [PinPromotionSummaryStatus](docs/PinPromotionSummaryStatus.md)
 - [PinUpdate](docs/PinUpdate.md)
 - [PinsList200Response](docs/PinsList200Response.md)
 - [PinsSaveRequest](docs/PinsSaveRequest.md)
 - [PinterestLibError](docs/PinterestLibError.md)
 - [PinterestLibPaginationOrder](docs/PinterestLibPaginationOrder.md)
 - [PinterestLibStatus204](docs/PinterestLibStatus204.md)
 - [PlacementGroupType](docs/PlacementGroupType.md)
 - [PlacementMultipliers](docs/PlacementMultipliers.md)
 - [PredictedTimeSeries](docs/PredictedTimeSeries.md)
 - [PriceFilter](docs/PriceFilter.md)
 - [ProductAvailabilityType](docs/ProductAvailabilityType.md)
 - [ProductCategoriesDemographic](docs/ProductCategoriesDemographic.md)
 - [ProductCategoriesEngagementType](docs/ProductCategoriesEngagementType.md)
 - [ProductCategoriesMetricsHighlights](docs/ProductCategoriesMetricsHighlights.md)
 - [ProductCategoryDetailLookbackWindow](docs/ProductCategoryDetailLookbackWindow.md)
 - [ProductCategoryDetails](docs/ProductCategoryDetails.md)
 - [ProductCategoryEnum](docs/ProductCategoryEnum.md)
 - [ProductCategoryRegion](docs/ProductCategoryRegion.md)
 - [ProductGroupAnalyticsResponseInner](docs/ProductGroupAnalyticsResponseInner.md)
 - [ProductGroupPromotion](docs/ProductGroupPromotion.md)
 - [ProductGroupPromotionCreateRequest](docs/ProductGroupPromotionCreateRequest.md)
 - [ProductGroupPromotionResponse](docs/ProductGroupPromotionResponse.md)
 - [ProductGroupPromotionResponseItem](docs/ProductGroupPromotionResponseItem.md)
 - [ProductGroupPromotionUpdateRequest](docs/ProductGroupPromotionUpdateRequest.md)
 - [ProductGroupPromotionsList200Response](docs/ProductGroupPromotionsList200Response.md)
 - [ProductGroupReferenceFilter](docs/ProductGroupReferenceFilter.md)
 - [ProductGroupSummaryStatus](docs/ProductGroupSummaryStatus.md)
 - [ProductType0Filter](docs/ProductType0Filter.md)
 - [ProductType1Filter](docs/ProductType1Filter.md)
 - [ProductType2Filter](docs/ProductType2Filter.md)
 - [ProductType3Filter](docs/ProductType3Filter.md)
 - [ProductType4Filter](docs/ProductType4Filter.md)
 - [PromotionArrayElement](docs/PromotionArrayElement.md)
 - [PromotionCommon](docs/PromotionCommon.md)
 - [PromotionCreateRequest](docs/PromotionCreateRequest.md)
 - [PromotionResponse](docs/PromotionResponse.md)
 - [PromotionTemplateValue](docs/PromotionTemplateValue.md)
 - [PromotionType](docs/PromotionType.md)
 - [PromotionUpdateRequest](docs/PromotionUpdateRequest.md)
 - [PromotionsList200Response](docs/PromotionsList200Response.md)
 - [PromotionsResponse](docs/PromotionsResponse.md)
 - [QualityComponentDetails](docs/QualityComponentDetails.md)
 - [QualityComponentIssue](docs/QualityComponentIssue.md)
 - [QualityComponents](docs/QualityComponents.md)
 - [QuizPinData](docs/QuizPinData.md)
 - [QuizPinOption](docs/QuizPinOption.md)
 - [QuizPinQuestion](docs/QuizPinQuestion.md)
 - [QuizPinResult](docs/QuizPinResult.md)
 - [RecordCounts](docs/RecordCounts.md)
 - [RelatedTerms](docs/RelatedTerms.md)
 - [RelatedTermsRelatedTermsListInner](docs/RelatedTermsRelatedTermsListInner.md)
 - [ReportingColumnAsync](docs/ReportingColumnAsync.md)
 - [ReportingTimeZone](docs/ReportingTimeZone.md)
 - [ReportsStats200Response](docs/ReportsStats200Response.md)
 - [ReportsStatsParametersParameter](docs/ReportsStatsParametersParameter.md)
 - [RespondToInvitesResponseArray](docs/RespondToInvitesResponseArray.md)
 - [RespondToInvitesResponseArrayItemsInner](docs/RespondToInvitesResponseArrayItemsInner.md)
 - [Role](docs/Role.md)
 - [S3FilePart](docs/S3FilePart.md)
 - [S3MultipartUploadData](docs/S3MultipartUploadData.md)
 - [SSIOAccountAddress](docs/SSIOAccountAddress.md)
 - [SSIOAccountItem](docs/SSIOAccountItem.md)
 - [SSIOAccountPMPName](docs/SSIOAccountPMPName.md)
 - [SSIOAccountResponse](docs/SSIOAccountResponse.md)
 - [SSIOCreateInsertionOrderRequest](docs/SSIOCreateInsertionOrderRequest.md)
 - [SSIOCreateInsertionOrderResponse](docs/SSIOCreateInsertionOrderResponse.md)
 - [SSIOEditInsertionOrderRequest](docs/SSIOEditInsertionOrderRequest.md)
 - [SSIOEditInsertionOrderResponse](docs/SSIOEditInsertionOrderResponse.md)
 - [SSIOInsertionOrderCommon](docs/SSIOInsertionOrderCommon.md)
 - [SSIOInsertionOrderStatus](docs/SSIOInsertionOrderStatus.md)
 - [SSIOInsertionOrderStatusResponse](docs/SSIOInsertionOrderStatusResponse.md)
 - [SSIOOrderLine](docs/SSIOOrderLine.md)
 - [SearchPartnerPins200Response](docs/SearchPartnerPins200Response.md)
 - [SearchUserBoardsGet200Response](docs/SearchUserBoardsGet200Response.md)
 - [SearchUserPinsList200Response](docs/SearchUserPinsList200Response.md)
 - [SharedAudience](docs/SharedAudience.md)
 - [SharedAudienceAccount](docs/SharedAudienceAccount.md)
 - [SharedAudienceCommon](docs/SharedAudienceCommon.md)
 - [SharedAudienceResponse](docs/SharedAudienceResponse.md)
 - [SharedAudienceResponseCommon](docs/SharedAudienceResponseCommon.md)
 - [SingleInterestTargetingOptionResponse](docs/SingleInterestTargetingOptionResponse.md)
 - [SourcePlatformOptions](docs/SourcePlatformOptions.md)
 - [SsioInsertionOrdersStatusGetByAdAccount200Response](docs/SsioInsertionOrdersStatusGetByAdAccount200Response.md)
 - [SsioOrderLinesGetByAdAccount200Response](docs/SsioOrderLinesGetByAdAccount200Response.md)
 - [SummaryPin](docs/SummaryPin.md)
 - [SystemUserUpdateRequest](docs/SystemUserUpdateRequest.md)
 - [TargetingAdvertiserCountry](docs/TargetingAdvertiserCountry.md)
 - [TargetingSpec](docs/TargetingSpec.md)
 - [TargetingSpecAgeBucket](docs/TargetingSpecAgeBucket.md)
 - [TargetingSpecAppType](docs/TargetingSpecAppType.md)
 - [TargetingSpecGender](docs/TargetingSpecGender.md)
 - [TargetingSpecOperationAgeBucket](docs/TargetingSpecOperationAgeBucket.md)
 - [TargetingSpecOperationAppType](docs/TargetingSpecOperationAppType.md)
 - [TargetingSpecOperationGender](docs/TargetingSpecOperationGender.md)
 - [TargetingSpecOperationList](docs/TargetingSpecOperationList.md)
 - [TargetingSpecOperationMinMaxAge](docs/TargetingSpecOperationMinMaxAge.md)
 - [TargetingSpecOperationShoppingRetargeting](docs/TargetingSpecOperationShoppingRetargeting.md)
 - [TargetingSpecOperationString](docs/TargetingSpecOperationString.md)
 - [TargetingSpecShoppingRetargeting](docs/TargetingSpecShoppingRetargeting.md)
 - [TargetingTemplateAudienceSizing](docs/TargetingTemplateAudienceSizing.md)
 - [TargetingTemplateAudienceSizingReachEstimate](docs/TargetingTemplateAudienceSizingReachEstimate.md)
 - [TargetingTemplateCommon](docs/TargetingTemplateCommon.md)
 - [TargetingTemplateCreate](docs/TargetingTemplateCreate.md)
 - [TargetingTemplateGetResponseData](docs/TargetingTemplateGetResponseData.md)
 - [TargetingTemplateKeyword](docs/TargetingTemplateKeyword.md)
 - [TargetingTemplateList200Response](docs/TargetingTemplateList200Response.md)
 - [TargetingTemplateResponseData](docs/TargetingTemplateResponseData.md)
 - [TargetingTemplateUpdateRequest](docs/TargetingTemplateUpdateRequest.md)
 - [TargetingTypeFilter](docs/TargetingTypeFilter.md)
 - [TemplateBasedReport](docs/TemplateBasedReport.md)
 - [TemplateResponse](docs/TemplateResponse.md)
 - [TemplateResponseDateRange](docs/TemplateResponseDateRange.md)
 - [TemplateResponseDateRangeAbsoluteDateRange](docs/TemplateResponseDateRangeAbsoluteDateRange.md)
 - [TemplateResponseDateRangeDynamicDateRange](docs/TemplateResponseDateRangeDynamicDateRange.md)
 - [TemplateResponseDateRangeRelativeDateRange](docs/TemplateResponseDateRangeRelativeDateRange.md)
 - [TemplatesList200Response](docs/TemplatesList200Response.md)
 - [TermsOfService](docs/TermsOfService.md)
 - [TimeSeries](docs/TimeSeries.md)
 - [TitleKeywordsFilter](docs/TitleKeywordsFilter.md)
 - [TopPinsAnalyticsResponse](docs/TopPinsAnalyticsResponse.md)
 - [TopPinsAnalyticsResponseDateAvailability](docs/TopPinsAnalyticsResponseDateAvailability.md)
 - [TopPinsAnalyticsResponsePinsInner](docs/TopPinsAnalyticsResponsePinsInner.md)
 - [TopVideoPinsAnalyticsResponse](docs/TopVideoPinsAnalyticsResponse.md)
 - [TopVideoPinsAnalyticsResponsePinsInner](docs/TopVideoPinsAnalyticsResponsePinsInner.md)
 - [TrackingUrls](docs/TrackingUrls.md)
 - [TrendType](docs/TrendType.md)
 - [TrendingKeyword](docs/TrendingKeyword.md)
 - [TrendingKeywordDemographics](docs/TrendingKeywordDemographics.md)
 - [TrendingKeywordDemographicsAgeDistribution](docs/TrendingKeywordDemographicsAgeDistribution.md)
 - [TrendingKeywordDemographicsGenderDistribution](docs/TrendingKeywordDemographicsGenderDistribution.md)
 - [TrendingKeywordsResponse](docs/TrendingKeywordsResponse.md)
 - [TrendingPin](docs/TrendingPin.md)
 - [TrendingProductCategory](docs/TrendingProductCategory.md)
 - [TrendingTopic](docs/TrendingTopic.md)
 - [TrendsSupportedRegion](docs/TrendsSupportedRegion.md)
 - [UpdatableItemAttributes](docs/UpdatableItemAttributes.md)
 - [UpdatableItemAttributesGtin](docs/UpdatableItemAttributesGtin.md)
 - [UpdateAssetGroupBody](docs/UpdateAssetGroupBody.md)
 - [UpdateAssetGroupBodyAssetGroupsToUpdateInner](docs/UpdateAssetGroupBodyAssetGroupsToUpdateInner.md)
 - [UpdateAssetGroupResponse](docs/UpdateAssetGroupResponse.md)
 - [UpdateAssetGroupResponseExceptionsInner](docs/UpdateAssetGroupResponseExceptionsInner.md)
 - [UpdateInvitesResultsResponseArray](docs/UpdateInvitesResultsResponseArray.md)
 - [UpdateInvitesResultsResponseArrayItemsInner](docs/UpdateInvitesResultsResponseArrayItemsInner.md)
 - [UpdateMaskBidOptionField](docs/UpdateMaskBidOptionField.md)
 - [UpdateMaskFieldType](docs/UpdateMaskFieldType.md)
 - [UpdateMemberAssetAccessBody](docs/UpdateMemberAssetAccessBody.md)
 - [UpdateMemberAssetAccessBodyAccessesInner](docs/UpdateMemberAssetAccessBodyAccessesInner.md)
 - [UpdateMemberAssetsResultsResponseArray](docs/UpdateMemberAssetsResultsResponseArray.md)
 - [UpdateMemberAssetsResultsResponseArrayItemsInner](docs/UpdateMemberAssetsResultsResponseArrayItemsInner.md)
 - [UpdateMemberBusinessRoleBody](docs/UpdateMemberBusinessRoleBody.md)
 - [UpdateMemberResult](docs/UpdateMemberResult.md)
 - [UpdateMemberResultsResponseArray](docs/UpdateMemberResultsResponseArray.md)
 - [UpdatePartnerAssetAccessBody](docs/UpdatePartnerAssetAccessBody.md)
 - [UpdatePartnerAssetAccessBodyAccessesInner](docs/UpdatePartnerAssetAccessBodyAccessesInner.md)
 - [UpdatePartnerAssetsResult](docs/UpdatePartnerAssetsResult.md)
 - [UpdatePartnerAssetsResultsResponseArray](docs/UpdatePartnerAssetsResultsResponseArray.md)
 - [UpdatePartnerResultsResponseArray](docs/UpdatePartnerResultsResponseArray.md)
 - [UpdatePartnerResultsResponseArrayItemsInner](docs/UpdatePartnerResultsResponseArrayItemsInner.md)
 - [UserAccountFollowedInterests200Response](docs/UserAccountFollowedInterests200Response.md)
 - [UserBusinessRoleBinding](docs/UserBusinessRoleBinding.md)
 - [UserFollowingFeedType](docs/UserFollowingFeedType.md)
 - [UserFollowingGet200Response](docs/UserFollowingGet200Response.md)
 - [UserListOperationType](docs/UserListOperationType.md)
 - [UserListType](docs/UserListType.md)
 - [UserSingleAssetBinding](docs/UserSingleAssetBinding.md)
 - [UserSummary](docs/UserSummary.md)
 - [UserWebsiteSummary](docs/UserWebsiteSummary.md)
 - [UserWebsiteVerificationCode](docs/UserWebsiteVerificationCode.md)
 - [UserWebsiteVerifyRequest](docs/UserWebsiteVerifyRequest.md)
 - [UserWebsitesGet200Response](docs/UserWebsitesGet200Response.md)
 - [UsersForIndividualAssetResponse](docs/UsersForIndividualAssetResponse.md)
 - [VerticalProductCategory](docs/VerticalProductCategory.md)
 - [VideoMetadataWithItemType](docs/VideoMetadataWithItemType.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="pinterest_oauth2"></a>
### pinterest_oauth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://www.pinterest.com/oauth/
- **Scopes**: 
 - **ads:read**: See all of your advertising data, including ads, ad groups, campaigns etc.
 - **ads:write**: Create, update, or delete ads, ad groups, campaigns etc.
 - **billing:read**: See all of your billing data, billing profile, etc.
 - **billing:write**: Create, update, or delete billing data, billing profiles, etc.
 - **biz_access:read**: See business access data
 - **biz_access:write**: Create, update, or delete business access data
 - **boards:read**: See your public boards, including group boards you join
 - **boards:read_secret**: See your secret boards
 - **boards:write**: Create, update, or delete your public boards
 - **boards:write_secret**: Create, update, or delete your secret boards
 - **catalogs:read**: See all of your catalogs data
 - **catalogs:write**: Create, update, or delete your catalogs data
 - **msot:write**: Create measurement source of truth events
 - **pins:read**: See your public Pins
 - **pins:read_secret**: See your secret Pins
 - **pins:write**: Create, update, or delete your public Pins
 - **pins:write_secret**: Create, update, or delete your secret Pins
 - **user_accounts:read**: See your user accounts and followers
 - **user_accounts:write**: Update your user accounts and followers

<a id="conversion_token"></a>
### conversion_token

- **Type**: Bearer authentication

<a id="basic"></a>
### basic

- **Type**: HTTP basic authentication

<a id="client_credentials"></a>
### client_credentials

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - **ads:read**: See all of your advertising data, including ads, ad groups, campaigns etc.
 - **ads:write**: Create, update, or delete ads, ad groups, campaigns etc.
 - **billing:read**: See all of your billing data, billing profile, etc.
 - **billing:write**: Create, update, or delete billing data, billing profiles, etc.
 - **biz_access:read**: See business access data
 - **biz_access:write**: Create, update, or delete business access data
 - **boards:read**: See your public boards, including group boards you join
 - **boards:read_secret**: See your secret boards
 - **boards:write**: Create, update, or delete your public boards
 - **boards:write_secret**: Create, update, or delete your secret boards
 - **catalogs:read**: See all of your catalogs data
 - **catalogs:write**: Create, update, or delete your catalogs data
 - **msot:write**: Create measurement source of truth events
 - **pins:read**: See your public Pins
 - **pins:read_secret**: See your secret Pins
 - **pins:write**: Create, update, or delete your public Pins
 - **pins:write_secret**: Create, update, or delete your secret Pins
 - **user_accounts:read**: See your user accounts and followers
 - **user_accounts:write**: Update your user accounts and followers


## Author

blah+oapicf@cliffano.com


